@@ -449,6 +449,8 @@ class FlowbladeApplication(Gtk.Application):
             GLib.idle_add(_create_sdl_2_consumer)
 
         self.add_window(_window)
+        if editorpersistance.prefs.global_layout != appconsts.SINGLE_WINDOW:
+            self.add_window(gui.editor_window.window2)
 
 # --------------------------------------- display
 def _create_sdl_2_consumer():
@@ -478,11 +480,13 @@ def monkeypatch_callbacks():
     callbackbridge.compositeeditor_get_compositor = compositeeditor.get_compositor
     callbackbridge.compositormodes_get_snapped_x = compositormodes.get_snapped_x
     callbackbridge.compositormodes_get_pointer_context = compositormodes.get_pointer_context
+    callbackbridge.dialogs_show_cyclic_error = dialogs.show_cyclic_error 
     callbackbridge.editevent_do_multiple_clip_insert = editevent.do_multiple_clip_insert
     callbackbridge.medialog_clips_drop = medialog.clips_drop
     callbackbridge.mediaplugin_get_clip = mediaplugin.get_clip
     callbackbridge.mediaplugin_set_plugin_to_be_edited = mediaplugin.set_plugin_to_be_edited
     callbackbridge.modesetting_set_default_edit_mode = modesetting.set_default_edit_mode
+    callbackbridge.modesetting_kftool_mode_from_kf_editor = modesetting.kftool_mode_from_kf_editor
     callbackbridge.movemodes_select_clip = movemodes.select_clip
     callbackbridge.movemodes_select_from_box_selection = movemodes.select_from_box_selection
     callbackbridge.projectaction_open_rendered_file = projectaction.open_rendered_file
@@ -561,6 +565,8 @@ def create_gui():
     editorlayout.set_positions_frames_visibility()
         
     # All widgets are now realized and references captured so can find out theme colors.
+    # TODO: Delete this code, we are not detecting anything anymore and theme colors not
+    # variable anymore.
     gui.set_theme_colors()
     tlinewidgets.set_dark_bg_color()
     gui.pos_bar.set_dark_bg_color()
@@ -1190,13 +1196,13 @@ def _app_destroy():
     stop_usb_hid_input()
 
     # Now that autosave file is deleted, the data folder contents for unsaved
-    # projects are unreachable and can be destoyed.
+    # projects are unreachable and can be destroyed.
     projectdatavault.delete_unsaved_data_folders()
 
     # Calling _app.quit() will block if Gio.Application.hold() has been called,
     # and the documentation helpfully says "(Note that you may have called 
     # Gio.Application.hold() indirectly, for example through gtk_application_add_window().)"
-    # I'm not calling add_window() on render processess but somehow those call Gio.Application.hold()
+    # I'm not calling add_window() on render processes but somehow those call Gio.Application.hold()
     # but I don't know where. 
     #
     # However, those processes complete and exit cleanly and the only problem 
