@@ -27,9 +27,11 @@ from PIL import Image
 from gi.repository import GLib
 from gi.repository import Gtk
 
+import copy
 from operator import itemgetter
 import os
 import time
+import hashlib
 
 import audiosync
 import appconsts
@@ -53,12 +55,14 @@ import modesetting
 import movemodes
 import projectaction
 import render
+import renderconsumer
 import singletracktransition
 import syncsplitevent
 import titler
 import tlinewidgets
 import tlineaction
 import updater
+import userfolders
 import utils
 
 # --------------------------------------------- menu data for each invocation.
@@ -472,7 +476,48 @@ def _delete_clip(data):
 
 def _lift(data):
     tlineaction.lift_button_pressed()
+
+def _ripple_delete(data):
+    clip, track, item_id, item_data = data
+    clip_index = track.clips.index(clip)
+    clip_start_in_tline = track.clip_start(clip_index)
+    clip_end_in_tline = clip_start_in_tline + (clip.clip_out - clip.clip_in)
+
+    orig_mark_in = current_sequence().tractor.mark_in 
+    orig_mark_out = current_sequence().tractor.mark_out
     
+    current_sequence().tractor.mark_in = clip_start_in_tline
+    current_sequence().tractor.mark_out = clip_end_in_tline
+
+    tlineaction.delete_range_button_pressed()
+
+    current_sequence().tractor.mark_in = orig_mark_in
+    current_sequence().tractor.mark_out = orig_mark_out
+    
+    updater.repaint_tline()
+
+def _ripple_delete_selection(data):
+    clip, track, item_id, item_data = data
+
+    start_clip_start_in_tline = track.clip_start(movemodes.selected_range_in)
+
+    end_clip = track.clips[movemodes.selected_range_out]
+    end_clip_start_in_tline = track.clip_start(movemodes.selected_range_out)
+    end_clip_end_in_tline = end_clip_start_in_tline + (end_clip.clip_out - end_clip.clip_in)
+
+    orig_mark_in = current_sequence().tractor.mark_in 
+    orig_mark_out = current_sequence().tractor.mark_out
+    
+    current_sequence().tractor.mark_in = start_clip_start_in_tline
+    current_sequence().tractor.mark_out = end_clip_end_in_tline
+
+    tlineaction.delete_range_button_pressed()
+
+    current_sequence().tractor.mark_in = orig_mark_in
+    current_sequence().tractor.mark_out = orig_mark_out
+    
+    updater.repaint_tline()
+
 def _set_length(data):
     clip, track, item_id, item_data = data
     dialogs.clip_length_change_dialog(_change_clip_length_dialog_callback, clip, track)
@@ -707,8 +752,10 @@ def _paste_filters(data):
     source_clip = paste_clips[0]
 
     # Currently selected clips are target clips
-    target_clips = [clip]
-    
+    target_clips = []
+    for i in range(movemodes.selected_range_in, movemodes.selected_range_out + 1):
+         target_clips.append(track.clips[i])
+
     actions = []    
     for target_clip in target_clips:
         data = {"clip":target_clip,"clone_source_clip":source_clip}
@@ -777,6 +824,32 @@ def _select_all_before(data):
     movemodes._select_multiple_clips(track.id, 0, track.clips.index(clip))
     updater.repaint_tline()
 
+def _mark_clip_range(data):
+    clip, track, item_id, item_data = data
+
+    clip_index = track.clips.index(clip)
+    clip_start_in_tline = track.clip_start(clip_index)
+    clip_end_in_tline = clip_start_in_tline + (clip.clip_out - clip.clip_in)
+    
+    current_sequence().tractor.mark_in = clip_start_in_tline
+    current_sequence().tractor.mark_out = clip_end_in_tline
+
+    updater.repaint_tline()
+
+def _mark_selection_range(data):
+    clip, track, item_id, item_data = data
+
+    start_clip_start_in_tline = track.clip_start(movemodes.selected_range_in)
+
+    end_clip = track.clips[movemodes.selected_range_out]
+    end_clip_start_in_tline = track.clip_start(movemodes.selected_range_out)
+    end_clip_end_in_tline = end_clip_start_in_tline + (end_clip.clip_out - end_clip.clip_in)
+    
+    current_sequence().tractor.mark_in = start_clip_start_in_tline
+    current_sequence().tractor.mark_out = end_clip_end_in_tline
+    
+    updater.repaint_tline()
+    
 def _add_clip_marker(data):
     clip, track, item_id, item_data = data
     current_frame = PLAYER().current_frame()
@@ -788,7 +861,6 @@ def _add_clip_marker(data):
         current_frame_clip = None
     
     if current_frame_clip != clip:
-        # Playhead is not on popup clip
         return
 
     clip_start_in_tline = track.clip_start(current_frame_clip_index)
@@ -887,23 +959,78 @@ def _split_audio_synched(data):
 def _set_audio_sync_clip(data):
     audiosync.init_select_tline_sync_clip(_get_data_with_xpos(data))
 
+def _set_container_default_enconding(data):
+    containerclip.set_project_default_video_endoding(data)
+
 def _render_tline_generator(data):
     clip, track, item_id, item_data = data
     clip, track, x = _popover_clip_data
     containerclip.render_tline_generator_clip(clip, _render_tline_generator_callback)
 
 def _render_tline_generator_callback(combo):
+    # Use selected render options are saved in clip.container_data.render_data 
     clip, track, x = _popover_clip_data
-    render_data = (clip, None, None, None) # We keep old data package format for now.
+    render_data_packet = (clip, None, None, None) # We keep old data package format for now.
     if combo.get_active() == 0: # 0 is render full media, see containeractions.set_video_endoding()
-        containerclip.render_full_media(render_data)
+        containerclip.render_full_media(render_data_packet)
     else:
-        containerclip.render_clip_length(render_data)
+        containerclip.render_clip_length(render_data_packet)
 
     """
     TODO: see if "cc_render_full_media", "cc_render_settings" can be deleted below.
     """
 
+def _update_seq_link(data):
+    clip, track, item_id, item_data = data
+
+    link_sequence = PROJECT().get_sequence_for_uid(clip.link_seq_data)
+    if link_sequence == None:
+        # Sequence has been deleted.
+        # TODO: info
+        return 
+
+    # Create unique file path in hidden render folder
+    folder = userfolders.get_render_dir()
+    uuid_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
+    write_file = folder + uuid_str + ".xml"
+    
+    render_player = renderconsumer.XMLRenderPlayer( write_file, _sequence_link_update_xml_render_done_callback, 
+                                                    (clip, track, write_file), link_sequence, 
+                                                    PROJECT(), PLAYER())
+    render_player.start()
+
+def _sequence_link_update_xml_render_done_callback(data):
+    # We need to do this in a Gdk lock holding thread because it does GUI updates.
+    GLib.idle_add(_do_seq_link_tline_edit, data)
+
+def _do_seq_link_tline_edit(data):
+    # We do GUI updates on add, so we need GLib thread.
+    clip, track, write_file = data
+
+    # Container clips, create new container_data object and generate uuid for clip so it gets it own folder in.$XML_DATA/.../container_clips
+    new_clip = current_sequence().create_file_producer_clip(write_file, clip.name, False, clip.ttl)
+    new_clip.container_data = copy.deepcopy(clip.container_data)
+    # Unlike every other seq link update clip replace we need updated container data, e.g. 'unrendered_media' in container data is different between 
+    # new clip and old clip, and 'unrendered_media' is used if this updated xml clip is rendered.
+    new_clip.container_data.unrendered_media = write_file
+    new_clip.container_data.program = write_file # for consistencys sake, not used in this container type.
+    new_clip.container_data.rendered_media = None # updated sequence has not been rendered to video.
+    new_clip.container_data.rendered_media_range_in = -1
+    new_clip.container_data.rendered_media_range_out = -1
+    new_clip.container_data.unrendered_length = new_clip.get_length() - 1
+    new_clip.link_seq_data = copy.deepcopy(clip.link_seq_data)
+    
+    clip_index = track.clips.index(clip)
+    
+    data = {"old_clip":clip,
+            "new_clip":new_clip,
+            "track":track,
+            "index":clip_index, 
+            "clip_in":clip.clip_in, 
+            "clip_out":clip.clip_out}
+    action = edit.clip_replace(data)
+    action.do_edit()
+    
 def _tline_clip_slowfast(data):
     clip, track, item_id, item_data = data
     render.render_slow_fast_timeline_clip(clip, track, _tline_clip_slow_fast_render_complete)
@@ -980,6 +1107,7 @@ def _revert_to_original_clip_from_slowmo_clip(data):
 # set as activation messages in guipopoverclip.py
 # activation_message -> _handler_func
 POPUP_HANDLERS = {"set_master":syncsplitevent.init_select_master_clip,
+                  "multi_set_master":syncsplitevent.init_select_master_clip,
                   "open_in_editor":_open_clip_in_effects_editor,
                   "clip_info":_show_clip_info,
                   "open_in_clip_monitor":_open_clip_in_clip_monitor,
@@ -988,10 +1116,12 @@ POPUP_HANDLERS = {"set_master":syncsplitevent.init_select_master_clip,
                   "split_audio":_split_audio,
                   "split_audio_synched":_split_audio_synched,
                   "resync":syncsplitevent.resync_clip,
+                  "multi_resync":syncsplitevent.resync_multi,
                   "add_filter":_add_filter,
                   "add_filter_multi":_add_filter_multi,
                   "add_compositor":_add_compositor,
                   "clear_sync_rel":syncsplitevent.clear_sync_relation,
+                  "multi_clear_sync_rel":syncsplitevent.clear_sync_relation_multi,
                   "mute_clip":_mute_clip,
                   "delete_blank":_delete_blank,
                   "cover_with_prev": _cover_blank_from_prev,
@@ -1003,8 +1133,12 @@ POPUP_HANDLERS = {"set_master":syncsplitevent.init_select_master_clip,
                   "clear_filters": _clear_filters,
                   "select_all_after": _select_all_after,
                   "select_all_before":_select_all_before,
+                  "mark_clip_range":_mark_clip_range,
+                  "mark_selection_range":_mark_selection_range,
                   "delete":_delete_clip,
-                  "lift":_lift, 
+                  "lift":_lift,
+                  "ripplerange":_ripple_delete,
+                  "ripplerangeselection":_ripple_delete_selection,
                   "length":_set_length,
                   "stretch_next":_stretch_next, 
                   "stretch_prev":_stretch_prev,
@@ -1027,10 +1161,13 @@ POPUP_HANDLERS = {"set_master":syncsplitevent.init_select_master_clip,
                   "multi_unmute_audio":_multi_unmute_audio,
                   "cc_render_full_media":containerclip.render_full_media,
                   "cc_render_clip":_render_tline_generator,
+                  "cc_set_encoding":_render_tline_generator,
+                  "cc_default_encoding":_set_container_default_enconding,
                   "cc_go_to_underdered":containerclip.switch_to_unrendered_media,
                   "cc_render_settings":containerclip.set_render_settings,
                   "cc_edit_program":containerclip.edit_program,
                   "cc_clone_generator":mediaplugin.add_media_plugin_clone,
+                  "cc_update_seq_link":_update_seq_link,
                   "edit_title":_edit_title,
                   "slowfast":_tline_clip_slowfast,
                   "revert":_revert_to_original_clip_from_slowmo_clip,
