@@ -20,6 +20,7 @@
 
 from gi.repository import Gtk, GLib
 
+import copy
 import hashlib
 import os
 import shutil
@@ -61,15 +62,17 @@ class ContainerClipData:
             self.container_clip_uid = -1 # This is set at clip creation time.
 
             self.container_type = container_type
-            self.program = program # path to program file
+            self.program = program # path to program file, used by Generators and Gmic containers.
 
-            self.rendered_media = None
+            self.rendered_media = None # lives in directory specified by 'self.container_clip_uid' in vault 'container_data' directory.
             self.rendered_media_range_in = -1
             self.rendered_media_range_out = -1
             self.last_render_type = containeractions.FULL_RENDER
             
-            self.unrendered_media = unrendered_media
+            self.unrendered_media = unrendered_media # 'unrendered_media' is created before ContainerClipData and 
+                                                     # lives in user file system (GMic) or vault 'rendered_clips' directory (rest).
             self.unrendered_length = None # This is also maximum length for media produced using this container data.
+                                          
             # This gets set later for some container types
             if unrendered_media != None:
                 self.unrendered_type = utils.get_media_type(unrendered_media)
@@ -112,7 +115,7 @@ class ContainerClipData:
 
 def render_tline_generator_clip(clip, callback):
     action_object = containeractions.get_action_object(clip.container_data)
-    action_object.set_video_endoding(None, callback, True)
+    action_object.set_video_endoding(None, callback, True) # All generator tline rendering goes via render settins and continues from given callback.
 
 def render_full_media(data):
     clip, track, item_id, item_data = data
@@ -143,6 +146,10 @@ def edit_program(data):
     action_object = containeractions.get_action_object(clip.container_data)
     action_object.edit_program(clip)
 
+def set_project_default_video_endoding(data):
+    clip, track, item_id, item_data = data
+    action_object = containeractions.get_action_object(clip.container_data)
+    action_object.set_project_default_video_endoding()
 
 #------------------------------------------------------------- Cloning
 def clone_clip(clip):
@@ -415,6 +422,13 @@ def create_mlt_xml_media_item(xml_file_path, media_name):
     _update_gui_for_media_object_add()
 
 
+# ---------------------------------------------------------------------- SEQUENCE LINK
+def create_sequence_link_media_item(xml_file_path, media_name, linked_sequence_uid):
+    container_clip_data = ContainerClipData(appconsts.CONTAINER_CLIP_SEQUENCE_LINK, xml_file_path, xml_file_path)
+    media_item = ContainerClipMediaItem(PROJECT().next_media_file_id, media_name, container_clip_data)
+    PROJECT().add_sequence_link_media_object(media_item, linked_sequence_uid)
+    _update_gui_for_media_object_add()
+    
 
 # ---------------------------------------------------------------- MEDIA FILE OBJECT
 
@@ -440,7 +454,8 @@ class ContainerClipMediaItem:
         self.has_proxy_file = False
         self.is_proxy_file = False
         self.second_file_path = None
-
+        self.link_seq_data = None
+        
         self.ttl = None
 
         self.current_frame = 0
@@ -454,6 +469,9 @@ class ContainerClipMediaItem:
         print("create_mlt_producer() not implemented")
 
     def create_icon(self):
+        # NOTE: self.container_data.unrendered_length GETS SET HERE!!!!
+        # it IS NOT VERY OBVIOUS OR EXPECTED THAT THIS IS THE PLACE WHERE THIS GETS DONE!!!
+        # TODO: CHANGE FUNCTION NAME.
         try:
             action_object = containeractions.get_action_object(self.container_data)
             if self.icon_path == None:
@@ -470,3 +488,12 @@ class ContainerClipMediaItem:
             cr, scaled_icon = containeractions._create_image_surface(self.icon_path)
             self.icon = scaled_icon
 
+# ---------------------------------------------------------------- cloning
+def container_clone(clone_clip, old_clip):
+    clone_clip.container_data = copy.deepcopy(old_clip.container_data)
+    clone_clip.container_data.generate_clip_id()
+
+    action_object = containeractions.get_action_object(clone_clip.container_data)
+    action_object.clone_container_data_files(old_clip)
+    
+    
\ No newline at end of file
