@@ -41,6 +41,7 @@ import mltenv
 import mltprofiles
 import mltfilters
 import mlttransitions
+import mltplayer
 import panels
 import projectdatavaultgui
 import projectdatavault
@@ -403,6 +404,38 @@ def load_media_plugin_plugin_properties(callback):
     dialog.connect('response', callback)
     dialog.show()
 
+def save_generator_template(callback, default_name, data):
+    dialog = Gtk.FileChooserDialog( _("Save Generator Template"), None,
+                                   Gtk.FileChooserAction.SAVE,
+                                   (_("Cancel"), Gtk.ResponseType.CANCEL,
+                                    _("Save"), Gtk.ResponseType.ACCEPT), None)
+    dialog.set_action(Gtk.FileChooserAction.SAVE)
+    dialog.set_current_name(default_name)
+    dialog.set_do_overwrite_confirmation(True)
+
+    dialog.set_select_multiple(False)
+    file_filter = Gtk.FileFilter()
+    file_filter.set_name(_("Flowblade Generator Template"))
+    file_filter.add_pattern("*" + "generatortemplate")
+    dialog.add_filter(file_filter)
+    
+    dialog.connect('response', callback, data)
+    dialog.show()
+
+def load_generator_template(callback):
+    dialog = Gtk.FileChooserDialog(_("Load Generator Properties"), None,
+                                   Gtk.FileChooserAction.OPEN,
+                                   (_("Cancel"), Gtk.ResponseType.CANCEL,
+                                    _("OK"), Gtk.ResponseType.ACCEPT))
+    dialog.set_action(Gtk.FileChooserAction.OPEN)
+    dialog.set_select_multiple(False)
+    file_filter = Gtk.FileFilter()
+    file_filter.set_name(_("Flowblade Generator Template"))
+    file_filter.add_pattern("*" + "generatortemplate")
+    dialog.add_filter(file_filter)
+    dialog.connect('response', callback)
+    dialog.show()
+    
 def get_media_plugin_length(callback, data):
     dialog = Gtk.Dialog(_("Create Cloned Media Item"), gui.editor_window.window,
                         Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
@@ -488,18 +521,6 @@ def compound_clip_name_dialog(callback, default_name, dialog_title, data=None):
         dialog.connect('response', callback, (data, name_entry))
     dialog.show_all()
     
-def save_env_data_dialog(callback):
-    dialog = Gtk.FileChooserDialog(_("Save Runtime Environment Data"),  gui.editor_window.window,
-                                   Gtk.FileChooserAction.SAVE,
-                                   (_("Cancel"), Gtk.ResponseType.CANCEL,
-                                   _("Save"), Gtk.ResponseType.ACCEPT))
-    dialog.set_action(Gtk.FileChooserAction.SAVE)
-    dialog.set_current_name("flowblade_runtime_environment_data")
-    dialog.set_do_overwrite_confirmation(True)
-    dialog.set_select_multiple(False)
-    dialog.connect('response', callback)
-    dialog.show()
-
 def save_cont_clip_edit_data(callback, default_name, edit_data):
     dialog = Gtk.FileChooserDialog(_("Save Container Clip Edit Data"),  gui.editor_window.window,
                                    Gtk.FileChooserAction.SAVE,
@@ -579,7 +600,7 @@ def about_dialog(parent_window):
     # Application tab
     img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
     flow_label = Gtk.Label(label="Flowblade Movie Editor")
-    ver_label = Gtk.Label(label="2.18.1")
+    ver_label = Gtk.Label(label="2.20")
     janne_label = Gtk.Label(label="Copyright 2024 Janne Liljeblad and contributors.")
     page_label = Gtk.Label(label=_("Project page:") + " " + "<a href=\"https://github.com/jliljebl/flowblade\">https://github.com/jliljebl/flowblade</a>")
     page_label.set_use_markup(True)
@@ -720,14 +741,20 @@ def environment_dialog(parent_window):
         run_type = "FLATPAK"
     else:
         run_type = _("DEVELOPER VERSION")
-
     r4 = guiutils.get_left_justified_box([Gtk.Label(label=_("Running from: ")), Gtk.Label(label=run_type)])
 
+    if mltplayer.get_sdl_consumer_version() == mltplayer.SDL_1:
+        p_ver = "SDL 1"
+    else:
+        p_ver = "SDL 2"
+    r5 = guiutils.get_left_justified_box([Gtk.Label(label=_("Consumer type: ")), Gtk.Label(label=p_ver)])
+
     vbox = Gtk.VBox(False, 4)
     vbox.pack_start(r1, False, False, 0)
     vbox.pack_start(r2, False, False, 0)
     vbox.pack_start(r3, False, False, 0)
     vbox.pack_start(r4, False, False, 0)
+    vbox.pack_start(r5, False, False, 0)
 
 
     filters = sorted(mltenv.services)
@@ -1121,7 +1148,7 @@ def replace_media_dialog(media_file, callback):
                 "\u2022" + _(" It is recommended that you save Project before completing this operation.\n") + \
                 "\u2022" + _(" There is no Undo for this operation.\n") + \
                 "\u2022" + _(" Current Undo Stack will be destroyed.\n") + \
-                "\u2022" + _(" Replacing current media with shorter or othervise unsuitable media may result in\n   crashes or corrupted project data.")
+                "\u2022" + _(" Replacing current media with shorter or otherwise unsuitable media may result in\n   crashes or corrupted project data.")
     info_label = Gtk.Label(label=info_text)
     info_label.set_use_markup(True)
     info_box = guiutils.get_left_justified_box([info_label])
@@ -1831,7 +1858,7 @@ def refuse_to_empty_default_notebook_dialog():
     dialogutils.info_message(primary_txt, secondary_txt, gui.editor_window.window)
 
 def active_jobs_info(active_jobs_count):
-    primary_txt =  _("There are currenly ") + str(active_jobs_count) + _(" active job/s!")
+    primary_txt =  _("There are currently ") + str(active_jobs_count) + _(" active job/s!")
     secondary_txt = _("Let active jobs complete or cancel them before closing the application.")
     dialogutils.info_message(primary_txt, secondary_txt, gui.editor_window.window)
 
@@ -1843,7 +1870,7 @@ def show_dead_compositors(number_of_dead_compositors):
 
 def no_timeline_ranges_dialog():
     primary_txt = _("Cannot log Ranges from Timelime!")
-    secondary_txt = _("'Range Log' functionality is intented to log areas of interest\nin Media Items.\n\nTo save interesting positions or ranges on Timeline use\nthe 'Timeline Markers' functionality.")
+    secondary_txt = _("'Range Log' functionality is intended to log areas of interest\nin Media Items.\n\nTo save interesting positions or ranges on Timeline use\nthe 'Timeline Markers' functionality.")
     dialogutils.info_message(primary_txt, secondary_txt, gui.editor_window.window)
 
 def add_compositor_dialog(compositors, callback):
@@ -1888,5 +1915,66 @@ def set_bin_grfx_default_length_dialog(bin, current_default_length, callback):
 
     dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, callback, value_spin)
 
+def set_parent_track_dialog(child_track, callback):
+    title = _("Set Track Clips Sync")
+    accept_text = _("Set")
+    
+    child_track_name = utils.get_track_name(child_track, editorstate.current_sequence())
+    label_text = _("Set Sync for all Clips on Track {} with Track:").format(child_track_name)
+    info_label = Gtk.Label(label=label_text)
+    info_label.set_margin_right(4)
 
-    
\ No newline at end of file
+    tracks_combo = Gtk.ComboBoxText()
+    selection_data = []
+    active_index = 0
+    for i in range(len(editorstate.current_sequence().tracks) - 2, 0, -1):
+        track = editorstate.current_sequence().tracks[i]
+        if track is child_track:
+            continue
+        selection_data.append(track)
+        tracks_combo.append_text(utils.get_track_name(track, editorstate.current_sequence()))
+
+    active_index = 0
+    for i in range(0, len(selection_data)):
+        if selection_data[i] is editorstate.current_sequence().first_video_track():
+            active_index = i
+    tracks_combo.set_active(active_index)
+
+    hbox = Gtk.HBox(False, 2)
+    hbox.pack_start(info_label, False, False, 0)
+    hbox.pack_start(tracks_combo, False, False, 0)
+
+    panel = dialogutils.get_alignment2(hbox)
+
+    dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, callback, (child_track, selection_data, tracks_combo))
+
+def select_link_sequence_for_container(callback):
+    title = _("Create Sequence Link Container Clip")
+    accept_text = _("Create Sequence Link Container")
+    
+    label_text = _("Create Sequence Link Container for Sequence:")
+    info_label = Gtk.Label(label=label_text)
+    info_label.set_margin_right(4)
+
+    sequences_combo = Gtk.ComboBoxText()
+    selection_data = []
+    active_index = 0
+    for i in range(0, len(editorstate.PROJECT().sequences)):
+        seq = editorstate.PROJECT().sequences[i]
+        selection_data.append(seq)
+        sequences_combo.append_text(seq.name)
+    sequences_combo.set_active(0)
+
+    hbox = Gtk.HBox(False, 2)
+    hbox.pack_start(info_label, False, False, 0)
+    hbox.pack_start(sequences_combo, False, False, 0)
+
+    panel = dialogutils.get_alignment2(hbox)
+
+    dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, callback, (sequences_combo, selection_data))
+    
+
+def show_cyclic_error():
+    primary_txt = _("Cyclic relation detected!")
+    secondary_txt = _("Edit would create a cyclink linked sequence relation and was cancelled!")
+    dialogutils.warning_message(primary_txt, secondary_txt, gui.editor_window.window)
