@@ -118,9 +118,9 @@ AVAILABLE_PANEL_POSITIONS_OPTIONS = { \
     appconsts.PANEL_FILTER_SELECT: [appconsts.PANEL_PLACEMENT_TOP_ROW_PROJECT_DEFAULT, appconsts.PANEL_PLACEMENT_TOP_ROW_RIGHT, appconsts.PANEL_PLACEMENT_BOTTOM_ROW_LEFT, appconsts.PANEL_PLACEMENT_BOTTOM_ROW_RIGHT, appconsts.PANEL_PLACEMENT_NOT_VISIBLE]
 }
 
-PANEL_ORDER_IN_NOTEBOOKS = [appconsts.PANEL_MEDIA, appconsts.PANEL_FILTER_SELECT, appconsts.PANEL_RANGE_LOG, 
+PANEL_ORDER_IN_NOTEBOOKS = [appconsts.PANEL_PROJECT, appconsts.PANEL_MEDIA, appconsts.PANEL_FILTER_SELECT, appconsts.PANEL_RANGE_LOG, 
                             appconsts.PANEL_MULTI_EDIT, appconsts.PANEL_JOBS, appconsts.PANEL_PROJECT_SMALL_SCREEN, 
-                            appconsts.PANEL_PROJECT, appconsts.PANEL_RENDERING,
+                            appconsts.PANEL_RENDERING,
                             appconsts.PANEL_MEDIA_AND_BINS_SMALL_SCREEN]
 
 PANEL_MINIMUM_SIZES = { \
@@ -205,10 +205,13 @@ def init_layout_data():
         if appconsts.PANEL_PROJECT in _panel_positions:
             _panel_positions[appconsts.PANEL_PROJECT_SMALL_SCREEN] = appconsts.PANEL_PLACEMENT_TOP_ROW_DEFAULT
             del(_panel_positions[appconsts.PANEL_PROJECT])
-    
+
     # Apply Filter Select panel width pref.
     PANEL_MINIMUM_SIZES[appconsts.PANEL_FILTER_SELECT] = (editorpersistance.prefs.filter_select_width, appconsts.TLINE_HEIGHT)
-
+    PANEL_MINIMUM_SIZES[appconsts.PANEL_PROJECT] = (editorpersistance.prefs.project_panel_width, appconsts.TLINE_HEIGHT)
+    PANEL_MINIMUM_SIZES[appconsts.PANEL_MULTI_EDIT] = (editorpersistance.prefs.editor_panel_width, appconsts.TLINE_HEIGHT)
+    PANEL_MINIMUM_SIZES[appconsts.PANEL_MEDIA] = (editorpersistance.prefs.media_panel_width, appconsts.TLINE_HEIGHT)
+    
     # Translations need to be initialized after modules have been loaded.
     _positions_names = { \
         appconsts.PANEL_PLACEMENT_TOP_ROW_DEFAULT: _("Top Row Default Notebook"),
