@@ -82,6 +82,7 @@ def load():
     prefs.buttons_style = NO_DECORATIONS 
     prefs.show_tool_tooltips = True
     prefs.theme = appconsts.FLOWBLADE_THEME_NEUTRAL
+    prefs.icons_scale = appconsts.ICONS_SCALE_DEFAULT
 
     try:
         recent_projects = utils.unpickle(recents_file_path)
@@ -117,7 +118,7 @@ def load():
             write_file = afw.get_file()
             pickle.dump(prefs, write_file)
         print("prefs updated to new version, new param count:", len(prefs.__dict__))
-        
+            
 def save():
     """
     Write out prefs and recent_projects files
@@ -192,7 +193,7 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     auto_center_check, play_pause_button, timeline_start_end_button, auto_center_on_updown, \
     ffwd_rev_shift_spin, ffwd_rev_caps_spin, follow_move_range, loop_clips = playback_prefs_widgets
     
-    force_language_combo, disp_splash, window_mode_combo, full_names, tracks_combo, icons_combo, project_panel_width_spin, \
+    force_language_combo, disp_splash, window_mode_combo, full_names, tracks_combo, project_panel_width_spin, \
     edit_panel_width_spin, media_panel_width_spin, layout_monitor, filter_select_width_spin = view_prefs_widgets
 
     perf_render_threads, perf_drop_frames = performance_widgets
@@ -230,7 +231,6 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.show_full_file_names = full_names.get_active()
     prefs.center_on_arrow_move = auto_center_on_updown.get_active()
     prefs.tracks_scale = tracks_combo.get_active()
-    prefs.icons_scale = icons_combo.get_active()
     prefs.playback_follow_move_tline_range = follow_move_range.get_active()
     prefs.auto_save_delay_value_index = autosave_combo.get_active()
     prefs.layout_display_index = layout_monitor.get_active()
@@ -383,7 +383,13 @@ class EditorPreferences:
         self.zoom_to_playhead = True
         self.filter_select_width = 220
         self.tracks_scale = appconsts.TRACKS_SCALE_DEFAULT
-        self.icons_scale = appconsts.ICONS_SCALE_DEFAULT
+        self.icons_scale = appconsts.ICONS_SCALE_DEFAULT  # DEPRECATED, we are not ever getting useful results with this.
         self.project_panel_width = PROJECT_PANEL_WIDTH_MIN
         self.editor_panel_width = EDIT_PANEL_WIDTH_MIN 
         self.media_panel_width = MEDIA_PANEL_WIDTH_MIN
+        self.sync_autosplit = appconsts.AUDIO_AUTO_SPLIT_OFF
+        self.sync_mirror = True
+        self.sync_dualtrim = False
+        self.show_sync = True
+        self.wide_multitrim_slip = False
+        self.disable_drag_when_selected = True
