@@ -74,6 +74,7 @@ import scripttool
 import shortcuts
 import shortcutsdialog
 import singletracktransition
+import syncsplitevent
 import titler
 import tlineaction
 import tlinecursors
@@ -373,6 +374,10 @@ class EditorWindow:
 
         # Effects select panel
         effect_select_panel, effect_select_list_view, effect_select_combo_box  = panels.get_effect_selection_panel(clipeffectseditor.effect_select_row_double_clicked)
+        # example code for using widget css from deleted test dev branch
+        #gui.apply_widget_css_class(effect_select_list_view.treeview, "bold-text", "bold-text-class.css")
+        #effect_select_list_view.treeview.set_name("light-text")
+        #gui.apply_widget_css(effect_select_list_view.treeview, "light-text", "light-text-id.css")
         self.effect_select_panel = effect_select_panel
         self.effect_select_list_view = effect_select_list_view
         self.effect_select_combo_box = effect_select_combo_box
@@ -514,19 +519,8 @@ class EditorWindow:
         self._create_monitor_buttons()
         self._create_monitor_row_widgets()
 
-        self.player_buttons = glassbuttons.PlayerButtons()
-        if (editorpersistance.prefs.play_pause == True):
-            if (editorpersistance.prefs.timeline_start_end is True):
-            # ------------------------------ timeline_start_end_button
-                tooltips = [_("Start - Home key"), _("End - End key"),_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play/Pause- Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            else:
-                tooltips = [_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play/Pause - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-        else:
-            if (editorpersistance.prefs.timeline_start_end is True):
-                tooltips = [_("Start - Home key"), _("End - End key"),_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play - Space"), _("Stop - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            else:
-                tooltips = [_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play - Space"), _("Stop - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            # ------------------------------End of timeline_start_end_button
+        self.player_buttons = glassbuttons.PlayerButtonsCompact()
+        tooltips = [_("Prev Frame - Arrow Left"),  _("Play/Pause - Space"), _("Next Frame - Arrow Right")]
         tooltip_runner = glassbuttons.TooltipRunner(self.player_buttons, tooltips)
         if editorpersistance.prefs.buttons_style == 2: # NO_DECORATIONS
             self.player_buttons.no_decorations = True
@@ -535,14 +529,33 @@ class EditorWindow:
         self.view_mode_select.widget.set_margin_end(10)
         self.trim_view_select = guicomponents.get_trim_view_select_launcher(monitorevent.trim_view_menu_launched)
 
+        callbacks = [monitorevent.mark_in_pressed,
+                     monitorevent.mark_out_pressed,
+                     monitorevent.marks_clear_pressed]
+        markbuttons = glassbuttons.MarkButtons(callbacks)
+        markbuttons.widget.set_margin_right(12)
+        mbtooltips = [_("Mark In - I"),  _("Mark Out - O"), _("Clear Marks - Alt + K")]
+        tooltip_runner = glassbuttons.TooltipRunner(markbuttons, mbtooltips)
+        
         player_buttons_row = Gtk.HBox(False, 0)
         player_buttons_row.pack_start(self.monitor_switch.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
+        #player_buttons_row.pack_start(self.monitor_clip_type.widget, False, False, 0)
+        #player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
         player_buttons_row.pack_start(self.player_buttons.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
+        #player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
+        player_buttons_row.pack_start(markbuttons.widget, False, False, 0)
         player_buttons_row.pack_start(self.trim_view_select.widget, False, False, 0)
         player_buttons_row.pack_start(self.view_mode_select.widget, False, False, 0)
-        player_buttons_row.set_margin_top(4)
+        player_buttons_row.set_margin_top(8)
+        player_buttons_row.set_margin_bottom(6)
+        player_buttons_row.set_margin_left(12)
+        player_buttons_row.set_margin_right(12)
+
+        player_buttons_row.set_name("player-bar")
+        gui.apply_widget_css(player_buttons_row, "player-bar", "player-bar-id.css")
+        
         self.player_buttons_row = player_buttons_row
 
         # Switch / pos bar row
@@ -575,7 +588,9 @@ class EditorWindow:
         guiutils.set_margins(self.edit_buttons_frame, 1, 0, 0, 0)
 
         self.edit_buttons_frame.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
-            
+        #self.edit_buttons_frame.set_name("middlebar")
+        #gui.apply_widget_css(player_buttons_row, "middlebar", "middlebar-id.css")
+                    
     def _init_tline(self):
         self.tline_scale = tlinewidgets.TimeLineFrameScale(modesetting.set_default_edit_mode,
                                                            updater.mouse_scroll_zoom)
@@ -589,11 +604,8 @@ class EditorWindow:
         info_h.pack_start(Gtk.Label(), True, True, 0)
         # Aug-2019 - SvdB - BB - Height doesn't need to be doubled. 1.4x is nicer
         size_adj = 1
-        size_x = tlinewidgets.COLUMN_WIDTH - 22 - 22 - 22
+        size_x = tlinewidgets.COLUMN_WIDTH - 22 - 22 - 22 - 22
         size_y = tlinewidgets.SCALE_HEIGHT
-        if editorpersistance.prefs.double_track_hights:
-            size_adj = 1.4
-            size_x = tlinewidgets.COLUMN_WIDTH - (66*size_adj)
 
         info_h.set_size_request(size_x, size_y)
 
@@ -607,9 +619,13 @@ class EditorWindow:
         levels_launcher_surface = guiutils.get_cairo_image("audio_levels_menu_launch")
         levels_launcher = guicomponents.PressLaunchPopover(trackaction.tline_properties_menu_launch_pressed, levels_launcher_surface, 22*size_adj, 22*size_adj)
 
+        sync_launcher_surface = guiutils.get_cairo_image("sync_menu_launch")
+        sync_launcher = guicomponents.PressLaunchPopover(syncsplitevent.sync_menu_launch_pressed, sync_launcher_surface, 22*size_adj, 22*size_adj)
+
         # Timeline top row
         tline_hbox_1 = Gtk.HBox()
         tline_hbox_1.pack_start(info_h, False, False, 0)
+        tline_hbox_1.pack_start(sync_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(levels_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(tracks_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(markers_launcher.widget, False, False, 0)
@@ -823,6 +839,7 @@ class EditorWindow:
             ('RangeOverWriteClip', None, _('Range Overwrite'), None, None, lambda a:tlineaction.range_overwrite_pressed()),
             ('CutClip', None, _('Cut Clip At Playhead'), None, None, lambda a:tlineaction.cut_pressed()),
             ('SequenceSplit', None, _('Split to new Sequence at Playhead Position'), None, None, lambda a:tlineaction.sequence_split_pressed()),
+            ('SequenceDuplicate', None, _('Duplicate Sequence'), None, None, lambda a:projectaction.duplicate_sequence()),
             ('DeleteClip', None, _('Lift'), None, None, lambda a:tlineaction.lift_button_pressed()),
             ('SpliceOutClip', None, _('Splice Out'), None, None, lambda a:tlineaction.splice_out_button_pressed()),
             ('ResyncSelected', None, _('Resync Track'),  resync_shortcut, None, lambda a:tlineaction.resync_button_pressed()),
@@ -861,6 +878,7 @@ class EditorWindow:
             ('LoadMediaPluginScript', None, _('Load Generator Script...'), None, None,lambda w: containerclip.create_fluxity_media_item()),
             ('CreateSelectionCompound', None, _('From Selected Clips'), None, None, lambda a:projectaction.create_selection_compound_clip()),
             ('CreateSequenceCompound', None, _('From Current Sequence'), None, None, lambda a:projectaction.create_sequence_compound_clip()),
+            ('CreateSequenceLinkContainerItem', None, _("Add Sequence Link Container Clip..."), None, None, lambda a:projectaction.create_sequence_link_container()),
             ('CreateSequenceFreezeCompound', None, _('From Current Sequence With Freeze Frame at Playhead Position'), None, None, lambda a:projectaction.create_sequence_freeze_frame_compound_clip()),
             ('AudioSyncCompoundClip', None, _('Audio Sync Merge Clip From 2 Media Items '), None, None, lambda a:audiosync.create_audio_sync_compound_clip()),
             ('ImportProjectMedia', None, _('Import Media From Project...'), None, None, lambda a:projectaction.import_project_media()),
@@ -974,6 +992,7 @@ class EditorWindow:
                         <separator/>
                         <menuitem action='CreateGMicContainerItem'/>
                     </menu>
+                    <menuitem action='CreateSequenceLinkContainerItem'/>
                     <separator/>
                     <menuitem action='AddMediaFolder'/>
                     <menuitem action='ImportProjectMedia'/>
@@ -1004,6 +1023,7 @@ class EditorWindow:
                     <separator/>
                     <menuitem action='CombineSequences'/>
                     <menuitem action='SequenceSplit'/>
+                    <menuitem action='SequenceDuplicate'/>
                     <separator/>
                     <menuitem action='AddVideoTrack'/>
                     <menuitem action='AddAudioTrack'/>
@@ -1230,15 +1250,6 @@ class EditorWindow:
             menu.append(new_item)
             new_item.show()
 
-    """
-    def hide_tline_render_strip(self):
-        guiutils.remove_children(self.tline_renderer_hbox)
-
-    def show_tline_render_strip(self):
-        self.tline_renderer_hbox.pack_start(self.pad_box, False, False, 0)
-        self.tline_renderer_hbox.pack_start(self.tline_render_strip.widget, True, True, 0)
-    """
-    
     def _change_windows_preference(self, widget, new_window_layout):
         if widget.get_active() == False:
             return
@@ -1299,6 +1310,11 @@ class EditorWindow:
     # ----------------------------------------------------------- GUI components monitor, middlebar.
     def _create_monitor_buttons(self):
         self.monitor_switch = guicomponents.MonitorSwitch(self._monitor_switch_handler)
+        self.monitor_switch.widget.set_margin_top(2)
+        self.monitor_switch.widget.set_margin_right(57)
+
+        self.monitor_clip_type = guicomponents.MonitorClipType()
+        #self.monitor_clip_type.widget.set_margin_right(17)
 
     def _create_monitor_row_widgets(self):
         self.monitor_tc_info = guicomponents.MonitorMarksTCInfo()
@@ -1312,54 +1328,11 @@ class EditorWindow:
             updater.display_clip_in_monitor()
 
     def connect_player(self, mltplayer):
-        # Buttons
-        # NOTE: ORDER OF CALLBACKS IS THE SAME AS ORDER OF BUTTONS FROM LEFT TO RIGHT
-        # Jul-2016 - SvdB - For play/pause button
-        if editorpersistance.prefs.play_pause == False:
-            # ------------------------------timeline_start_end_button
-            if (editorpersistance.prefs.timeline_start_end is True):
-                pressed_callback_funcs = [monitorevent.start_pressed,  #  go to start
-                                          monitorevent.end_pressed,   #  go to  end
-                                          monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.stop_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-            else:
-                pressed_callback_funcs = [monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.stop_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-        else:
-            if (editorpersistance.prefs.timeline_start_end is True):
-                pressed_callback_funcs = [monitorevent.start_pressed,  #  go to start
-                                          monitorevent.end_pressed,   #  go to  end
-                                          monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-            else:
-                pressed_callback_funcs = [monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
+
+        pressed_callback_funcs = [monitorevent.prev_pressed,
+                                  monitorevent.play_stop_pressed,
+                                  monitorevent.next_pressed]
+
 
         self.player_buttons.set_callbacks(pressed_callback_funcs)
 
