@@ -25,6 +25,7 @@ import cairoarea
 import editorpersistance
 import gui
 import guiutils
+import respaths
 
 BUTTONS_GRAD_STOPS = [   (1, 1, 1, 1, 0.2),
                         (0.8, 1, 1, 1, 0),
@@ -277,6 +278,7 @@ class AbstractGlassButtons:
             x += self.button_width
 
     def show_prelight_icons(self):
+        self.prelight_icons = []
         for icon in self.icons:
             surface_prelight = cairo.ImageSurface(cairo.FORMAT_ARGB32, icon.get_width(), icon.get_height())
             cr = cairo.Context(surface_prelight)
@@ -339,7 +341,7 @@ class PlayerButtons(AbstractGlassButtons):
                 self.icons = [prev_icon, next_icon, play_pause_icon,
                           mark_in_icon, mark_out_icon,
                           marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
-                self.image_x = [ 5*size_adj, 7*size_adj, 5*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
+                self.image_x = [ 5*size_adj, 7*size_adj, 11*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 0*size_adj]
         else:
             #  go to start end
             if (editorpersistance.prefs.timeline_start_end == True):
@@ -423,7 +425,110 @@ class PlayerButtons(AbstractGlassButtons):
         self.button_x = mid_x - (buttons_width // 2)
         self._draw_buttons(cr, w, h)
 
+class PlayerButtonsCompact(AbstractGlassButtons):
 
+    def __init__(self):
+        # Aug-2019 - SvdB - BB - Multiple changes - size_ind, size_adj, get_cairo_image
+        size_ind = 0
+        AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH[size_ind], MB_BUTTON_HEIGHT[size_ind], MB_BUTTON_Y, MB_BUTTONS_WIDTH[size_ind], MB_BUTTONS_HEIGHT[size_ind] - 2)
+
+        # Force no decorations for player buttons, this cannot be made to work.
+        self.no_decorations = True 
+
+        self.play_icon = guiutils.get_cairo_image("play_2_s")
+        self.stop_icon = guiutils.get_cairo_image("stop_s")
+        self.next_icon = guiutils.get_cairo_image("next_frame_s")
+        self.prev_icon = guiutils.get_cairo_image("prev_frame_s")
+
+        self.icons = [self.prev_icon, self.play_icon, self.next_icon]
+        self.image_x = [0, 0, -1]
+
+
+        for i in range(0, len(self.icons)):
+            self.image_y.append(MB_BUTTON_IMAGE_Y - 6)
+        
+        self.pressed_callback_funcs = None # set using set_callbacks()
+
+        self.set_sensitive(True)
+
+        focus_groups[DEFAULT_FOCUS_GROUP].append(self.widget)
+
+        self.show_prelight_icons()
+        self.stopped_prelight_icons = self.prelight_icons 
+        self.icons = [self.prev_icon, self.stop_icon, self.next_icon]
+        self.show_prelight_icons()
+        self.playing_prelight_icons = self.prelight_icons 
+        
+        self.icons = [self.prev_icon, self.play_icon, self.next_icon]
+        self.prelight_icons = self.stopped_prelight_icons 
+        
+    def set_normal_sensitive_pattern(self):
+        self.set_sensitive(True)
+        self.widget.queue_draw()
+
+    def show_playing_state(self, is_playing):
+        if is_playing == True:
+            self.icons = [self.prev_icon, self.stop_icon, self.next_icon]
+            self.prelight_icons = self.playing_prelight_icons 
+        else:
+            self.icons = [self.prev_icon, self.play_icon, self.next_icon]
+            self.prelight_icons = self.stopped_prelight_icons
+                
+        self.widget.queue_draw()
+        
+    # ------------------------------------------------------------- mouse events
+    def _press_event(self, event):
+        """
+        Mouse button callback
+        """
+        self.pressed_button = self._get_hit_code(event.x, event.y)
+        if self.pressed_button >= 0 and self.pressed_button < len(self.icons):
+            callback_func = self.pressed_callback_funcs[self.pressed_button] # index is set to match at editorwindow.py where callback func list is created
+            callback_func()
+        self.widget.queue_draw()
+
+    def _motion_notify_event(self, x, y, state):
+        """
+        Mouse move callback
+        """
+        button_under = self._get_hit_code(x, y)
+        if self.pressed_button != button_under: # pressed button is released
+            self.pressed_button = NO_HIT
+
+        if len(self.prelight_icons) > 0:
+            self.prelight_index = button_under
+            
+        self.widget.queue_draw()
+
+    def _release_event(self, event):
+        """
+        Mouse release callback
+        """
+        self.pressed_button = -1
+        self.widget.queue_draw()
+
+    def _leave_notify_event(self, event):
+        self.prelight_index = -1
+        self.widget.queue_draw()
+
+    def _enter_notify_event(self, event):
+        self.prelight_index = -1
+        
+    def set_callbacks(self, pressed_callback_funcs):
+        self.pressed_callback_funcs = pressed_callback_funcs
+
+    # ---------------------------------------------------------------- painting
+    def _draw(self, event, cr, allocation):
+        x, y, w, h = allocation
+        self.allocation = allocation
+
+        mid_x = w // 2
+        buttons_width = self.button_width * len(self.icons)
+        # Jul-2016 - SvdB - No changes made here, but because of the calculation of button_x the row of buttons is slightly moved right if play/pause
+        # is enabled. This could be solved by setting self.button_x = 1, if wished.
+        self.button_x = mid_x - (buttons_width // 2)
+        self._draw_buttons(cr, w, h)
+        
 class GmicButtons(AbstractGlassButtons):
 
     def __init__(self):
@@ -603,6 +708,19 @@ class GlassButtonsToggleGroup(GlassButtonsGroup):
         pass
 
 
+class MarkButtons(GlassButtonsGroup):
+    
+    def __init__(self, callbacks):
+            
+        GlassButtonsGroup.__init__(self, 16, 18, 0, 0, 2)
+            
+        self.add_button(cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "mark_in_xs.png"), callbacks[0])
+        self.add_button(cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "mark_out_xs.png"), callbacks[1])
+        self.add_button(cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "mark_clear_xs.png"), callbacks[2])
+        self.no_decorations = True 
+        
+        self.show_prelight_icons()
+
 
 class TooltipRunner:
 
