@@ -38,6 +38,9 @@ _markers_popover = None
 _markers_menu = None
 _tline_properties_popover = None
 _tline_properties_menu = None
+_sync_popover = None
+_sync_menu = None
+_autosync_split_submenu = None
 _all_tracks_popover = None
 _all_tracks_menu = None
 _compositing_mode_popover = None
@@ -66,6 +69,8 @@ _file_filter_popover = None
 _file_filter_menu = None
 _media_file_popover = None
 _media_file_menu = None
+_media_file_multi_popover = None
+_media_file_menu_multi = None
 _jobs_popover = None
 _jobs_menu = None
 _effects_popover = None
@@ -108,9 +113,10 @@ _mf_properties_section = None
 _icon_section = None
 _mf_render_section = None
 _mf_proxy_section = None
+_mf_stabilize_section = None
 
 
-# -------------------------------------------------- menuitems builder fuctions
+# -------------------------------------------------- menuitems builder functions
 def add_menu_action(menu, label, item_id, data, callback, active=True, app=None):
     if active == True:
         menu.append(label, "app." + item_id) 
@@ -238,6 +244,13 @@ def tline_properties_menu_show(launcher, widget, callback, mouse_zoom_callback):
 
     _tline_properties_menu = menu_clear_or_create(_tline_properties_menu)
 
+    wide_multitrim_is_on = editorpersistance.prefs.wide_multitrim_slip
+    disable_drag_when_selected_is_on = editorpersistance.prefs.disable_drag_when_selected
+    edit_prefs_section = Gio.Menu.new()
+    add_menu_action_check(edit_prefs_section, _("Disable Clip Ends Drag When Selected"), "midbar.tlineproperties.disabledrag", disable_drag_when_selected_is_on, "disabledrag", callback)
+    add_menu_action_check(edit_prefs_section, _("Wide Multitrim Slip Target Area"), "midbar.tlineproperties.wideslip", wide_multitrim_is_on, "wideslip", callback)
+    _tline_properties_menu.append_section(None, edit_prefs_section)
+
     display_section = Gio.Menu.new()
     add_menu_action_check(display_section, _("Display Clip Media Thumbnails"), "midbar.tlineproperties.thumb", editorstate.display_clip_media_thumbnails, "thumbs", callback)
     add_menu_action_check(display_section, _("Display Audio Levels"), "midbar.tlineproperties.all", editorstate.display_all_audio_levels, "all", callback)
@@ -258,13 +271,54 @@ def tline_properties_menu_show(launcher, widget, callback, mouse_zoom_callback):
     _tline_properties_menu.append_section(None, snapping_section)
 
     scrubbing_section = Gio.Menu.new()
-    add_menu_action_check(scrubbing_section, _("Audio scrubbing"), "midbar.tlineproperties.scrubbing", editorpersistance.prefs.audio_scrubbing, "scrubbing", callback)
+    add_menu_action_check(scrubbing_section, _("Audio Scrubbing"), "midbar.tlineproperties.scrubbing", editorpersistance.prefs.audio_scrubbing, "scrubbing", callback)
     _tline_properties_menu.append_section(None, scrubbing_section)
 
     _tline_properties_popover = Gtk.Popover.new_from_model(widget, _tline_properties_menu)
     launcher.connect_launched_menu(_tline_properties_popover)
     _tline_properties_popover.show()
 
+def sync_menu_show(launcher, widget, properties_set_callback, split_mirror_callback, sync_callback):
+    global _sync_popover, _sync_menu, _autosync_split_submenu
+
+    if _sync_menu == None:
+        _sync_menu = menu_clear_or_create(_sync_menu)
+            
+        properties_section = Gio.Menu.new()
+
+        
+        add_menu_action_check(properties_section, _("Show Synch Relations"), "midbar.sync.showsync", editorpersistance.prefs.show_sync, "showsync", properties_set_callback)
+        _sync_menu.append_section(None, properties_section)
+
+        mirror_section = Gio.Menu.new()
+        _autosync_split_submenu = menu_clear_or_create(_autosync_split_submenu)
+        items_data = [  ( _("Off"), str(appconsts.AUDIO_AUTO_SPLIT_OFF)), 
+                        (_("On All Video Tracks"), str(appconsts.AUDIO_AUTO_SPLIT_ALL_TACKS)),
+                        ( _("On Tracks V1 and V2"), str(appconsts.AUDIO_AUTO_SPLIT_V1_V2)), 
+                        ( _("On Track V1"), str(appconsts.AUDIO_AUTO_SPLIT_V1)) ]
+        active_index = editorpersistance.prefs.sync_autosplit
+        add_menu_action_all_items_radio(_autosync_split_submenu, items_data,  "midbar.sync.autosplit", active_index, sync_callback)
+        mirror_section.append_submenu(_("Auto Sync Split Video Clips on Add"), _autosync_split_submenu)
+        items_data =[(_("Audio Split To Mirrored Track"), "splitmirror"), (_("Audio Split To V1 Always"), "splitv1")]
+        if  editorpersistance.prefs.sync_mirror == True:
+            active_index = 0
+        else:
+            active_index = 1
+        add_menu_action_all_items_radio(mirror_section, items_data, "midbar.sync.mirror", active_index, split_mirror_callback)
+        _sync_menu.append_section(None, mirror_section)
+    else:
+        _autosync_split_submenu = menu_clear_or_create(_autosync_split_submenu)
+        items_data = [  ( _("Off"), str(appconsts.AUDIO_AUTO_SPLIT_OFF)), 
+                        (_("On All Video Tracks"), str(appconsts.AUDIO_AUTO_SPLIT_ALL_TACKS)),
+                        ( _("On Tracks V1 and V2"), str(appconsts.AUDIO_AUTO_SPLIT_V1_V2)), 
+                        ( _("On Track V1"), str(appconsts.AUDIO_AUTO_SPLIT_V1)) ]
+        active_index = editorpersistance.prefs.sync_autosplit
+        add_menu_action_all_items_radio(_autosync_split_submenu, items_data,  "midbar.sync.autosplit", active_index, sync_callback)
+    
+    _sync_popover = Gtk.Popover.new_from_model(widget, _sync_menu)
+    launcher.connect_launched_menu(_sync_popover)
+    _sync_popover.show()
+    
 def all_tracks_menu_show(launcher, widget, callback):
     global _all_tracks_popover, _all_tracks_menu
 
@@ -357,12 +411,13 @@ def sequence_panel_popover_show(widget, x, y, callback):
 
     main_section = Gio.Menu.new()
     add_menu_action(main_section, _("Add New Sequence"), "sequencepanel.add", "add sequence", callback)
-    add_menu_action(main_section, _("Edit Selected Sequence"), "sequencepanel.edit", "edit sequence", callback)
-    add_menu_action(main_section, _("Delete Selected Sequence"), "sequencepanel.delete", "delete sequence", callback)
+    add_menu_action(main_section, _("Edit"), "sequencepanel.edit", "edit sequence", callback)
+    add_menu_action(main_section, _("Delete"), "sequencepanel.delete", "delete sequence", callback)
     _sequence_panel_menu.append_section(None, main_section)
 
     container_section = Gio.Menu.new()
-    add_menu_action(container_section, _("Create Container Clip from Selected Sequence"), "sequencepanel.create", "compound clip", callback)
+    add_menu_action(container_section, _("Create Container Clip"), "sequencepanel.create", "container clip", callback)
+    add_menu_action(container_section, _("Create Sequence Link Container Clip"), "sequencepanel.createseqlink", "sequence link container clip", callback)
     _sequence_panel_menu.append_section(None, container_section)
 
     rect = create_rect(x, y)
@@ -480,6 +535,10 @@ def media_hamburger_popover_show(launcher, widget, callback):
     global _media_panel_hamburger_popover, _media_panel_hamburger_menu
 
     _media_panel_hamburger_menu = menu_clear_or_create(_media_panel_hamburger_menu)
+
+    delete_section = Gio.Menu.new()
+    add_menu_action(delete_section, _("Delete"), "mediapanel.delete", "delete", callback)
+    _media_panel_hamburger_menu.append_section(None, delete_section)
     
     proxy_section = Gio.Menu.new()
     add_menu_action(proxy_section, _("Render Proxy Files For Selected Media"), "mediapanel.proxyrender", "render proxies", callback)
@@ -548,8 +607,8 @@ def file_filter_popover_show(launcher, widget, callback):
 
         items_data =[( _("All Files"), "0"), (_("Video Files"), "1"), \
                     ( _("Audio Files"), "2"), (_("Graphics Files"), "3"), ( _("Image Sequences"), "4"), \
-                    (_("Pattern Producers"), "5"), (_("Unused Files"), "6")]
-                    
+                    (_("Containers"), "5"), (_("Unused Files"), "6")]
+
         active_index = editorstate.media_view_filter
         radio_section = Gio.Menu.new()
         add_menu_action_all_items_radio(radio_section, items_data, "mediapanel.fileview", active_index, callback)
@@ -574,7 +633,7 @@ def file_filter_popover_show(launcher, widget, callback):
 
 def media_file_popover_show(media_file, widget, x, y, callback, callback_rating):
     global _media_file_popover, _media_file_menu, _rated_section, _rated_submenu, _monitor_section, \
-    _mf_properties_section, _icon_section, _mf_render_section, _mf_proxy_section
+    _mf_properties_section, _icon_section, _mf_render_section, _mf_stabilize_section, _mf_proxy_section
 
     if _media_file_menu == None:
         _media_file_menu = menu_clear_or_create(_media_file_menu)
@@ -610,6 +669,10 @@ def media_file_popover_show(media_file, widget, x, y, callback, callback_rating)
         _fill_mf_render_section(_mf_render_section, media_file, callback)
         _media_file_menu.append_section(None, _mf_render_section)
 
+        _mf_stabilize_section  = Gio.Menu.new()
+        _fill_mf_stabilize_section(_mf_stabilize_section, media_file, callback)
+        _media_file_menu.append_section(None, _mf_stabilize_section)
+
         _mf_proxy_section = Gio.Menu.new()
         _fill_mf_proxy_section(_mf_proxy_section, media_file, callback)
         _media_file_menu.append_section(None, _mf_proxy_section)
@@ -633,12 +696,38 @@ def media_file_popover_show(media_file, widget, x, y, callback, callback_rating)
         menu_clear_or_create(_mf_render_section)
         _fill_mf_render_section(_mf_render_section, media_file, callback)
 
+        menu_clear_or_create(_mf_stabilize_section)
+        _fill_mf_stabilize_section(_mf_stabilize_section, media_file, callback)
+        
         menu_clear_or_create(_mf_proxy_section)
         _fill_mf_proxy_section(_mf_proxy_section, media_file, callback)
         
     rect = create_rect(x, y)
     _media_file_popover = new_mouse_popover(widget, _media_file_menu, rect)
 
+def media_file_popover_multi_show(widget, x, y, callback):
+    global _media_file_multi_popover, _media_file_menu_multi
+
+    if _media_file_menu_multi == None:
+        _media_file_menu_multi = menu_clear_or_create(_media_file_menu_multi)
+
+        file_action_section = Gio.Menu.new()
+        add_menu_action(file_action_section, _("Delete"), "mediapanel.mediafilemulti.delete", "Delete", callback)
+        _media_file_menu_multi.append_section(None, file_action_section)
+
+        media_item_action_section = Gio.Menu.new()
+        add_menu_action(media_item_action_section, _("Move to Clicked Position..."), "mediapanel.mediafilemulti.movetoclicked", "Move to Clicked Position", callback)
+        add_menu_action(media_item_action_section, _("Render Proxy File"), "mediapanel.mediafilemulti.proxy", "Render Proxy", callback)
+        _media_file_menu_multi.append_section(None, media_item_action_section)
+        
+        edit_action_section = Gio.Menu.new()
+        add_menu_action(edit_action_section, _("Append to Timeline"), "mediapanel.mediafilemulti.append", "Append to Timeline", callback)
+        _media_file_menu_multi.append_section(None, edit_action_section)
+            
+    rect = create_rect(x, y)
+    _media_file_multi_popover = new_mouse_popover(widget, _media_file_menu_multi, rect)
+
+
 def _fill_monitor_section(_monitor_section, media_file, callback):
     if hasattr(media_file, "container_data"): 
         if media_file.container_data == None:
@@ -681,6 +770,13 @@ def _fill_mf_proxy_section(_mf_proxy_section, media_file, callback):
 
     add_menu_action(_mf_proxy_section, _("Render Proxy File"), "mediapanel.mediafile.proxy", ("Render Proxy File", None), callback, active)
 
+def _fill_mf_stabilize_section(_mf_proxy_section, media_file, callback):
+    active = False
+    if media_file.type == appconsts.VIDEO or media_file.type == appconsts.IMAGE_SEQUENCE:
+        active = True
+
+    add_menu_action(_mf_proxy_section, _("Render Stabilized File"), "mediapanel.mediafile.stabilize", ("Render Stabilized File", None), callback, active)
+    
 def jobs_menu_popover_show(launcher, widget, callback):
     global _jobs_popover, _jobs_menu
 
@@ -905,8 +1001,21 @@ def tracks_popover_menu_show(track, widget, x, y, callback, callback_height):
 
     _tracks_column_menu.append_section(None, mute_section)
 
+    active = True
+
+    sync_set_section = Gio.Menu.new()
+    add_menu_action(sync_set_section, _("Sync All Clips to Track..."), "trackcolumn.sync.setsync",  (track,"setsync", None), callback, active)
+    reset_active = track_obj.parent_track != None
+    add_menu_action(sync_set_section, _("Update Sync to Clips' Current Positions"), "trackcolumn.sync.resetsync",  (track,"ressetsync", None), callback, reset_active)
+    add_menu_action(sync_set_section, _("Clear Sync"), "trackcolumn.sync.clearsync", (track,"clearsync", None), callback, active)
+    _tracks_column_menu.append_section(None, sync_set_section)
+
+    resync_section = Gio.Menu.new()
+    add_menu_action(resync_section, _("Resync Track"), "trackcolumn.sync.resync", (track,"resync", None), callback, active)
+    _tracks_column_menu.append_section(None, resync_section)
+
     rect = create_rect(x, y)
-    
+
     _tracks_column_popover = Gtk.Popover.new_from_model(widget, _tracks_column_menu)
     _tracks_column_popover.set_pointing_to(rect) 
     _tracks_column_popover.show()
