@@ -47,6 +47,7 @@ _tools_submenu = None
 _edit_bottom_section = None
 _compositor_section = None
 _title_section = None
+_generator_sub_menu = None
 _generator_section = None
 
 _audio_clip_popover = None
@@ -62,6 +63,7 @@ _blank_clip_menu = None
 _multi_clip_popover = None
 _multi_clip_menu = None
 _multi_audio_section = None
+_multi_sync_section = None
 
 _compositor_popover = None
 _compositor_menu = None
@@ -81,7 +83,7 @@ _kf_select_popover = None
 _kf_select_menu = None
  
  
-# -------------------------------------------------- menuitems builder fuctions
+# -------------------------------------------------- menuitems builder functions
 def add_menu_action(menu, label, item_id, data, callback, active=True, app=None):
     return guipopover.add_menu_action(menu, label, item_id, data, callback, active, app)
 
@@ -108,7 +110,7 @@ def clip_popover_menu_show(widget, clip, track, x, y, callback):
 
     global _clip_popover, _clip_menu, _audio_submenu, _markers_submenu, \
     _markers_submenu_static_items, _reload_section, _edit_actions_menu, \
-    _tools_submenu, _title_section, _compositor_section, _generator_section
+    _tools_submenu, _title_section, _compositor_section, _generator_section, _generator_sub_menu
 
     if _clip_menu == None:
         _clip_menu = guipopover.menu_clear_or_create(_clip_menu)
@@ -124,6 +126,8 @@ def clip_popover_menu_show(widget, clip, track, x, y, callback):
         _clip_menu.append_section(None, audio_section)
 
         _generator_section = Gio.Menu.new()
+        _generator_sub_menu = Gio.Menu.new()
+        _fill_generator_render_section(_generator_sub_menu, clip, callback)
         _fill_generator_section(_generator_section, clip, callback)
         _clip_menu.append_section(None, _generator_section)
         
@@ -171,8 +175,8 @@ def clip_popover_menu_show(widget, clip, track, x, y, callback):
         clone_sub_menu = Gio.Menu.new()
         _fill_clone_filters_menu(clone_sub_menu, callback, False, False)
         filters_copy_section.append_submenu(_("Clone Filter"), clone_sub_menu)
-        add_menu_action(filters_copy_section, _("Copy Filters"), "clipmenu.openinmonitor.copyfilters",  ("copy_filters", None), callback)
-        add_menu_action(filters_copy_section, _("Paste Filters"), "clipmenu.openinmonitor.pastefilters",  ("paste_filters", None), callback)
+        add_menu_action(filters_copy_section, _("Copy Filters"), "clipmenu.copyfilters",  ("copy_filters", None), callback)
+        add_menu_action(filters_copy_section, _("Paste Filters"), "clipmenu.pastefilters",  ("paste_filters", None), callback)
         _clip_menu.append_section(None, filters_copy_section)
 
         _title_section = Gio.Menu.new()
@@ -206,9 +210,12 @@ def clip_popover_menu_show(widget, clip, track, x, y, callback):
         guipopover.menu_clear_or_create(_title_section)
         _fill_title_section(_title_section, clip, callback)
 
+        guipopover.menu_clear_or_create(_generator_sub_menu)
+        _fill_generator_render_section(_generator_sub_menu, clip, callback)
+
         guipopover.menu_clear_or_create(_generator_section)
         _fill_generator_section(_generator_section, clip, callback)
-
+        
     rect = guipopover.create_rect(x, y)
     _clip_popover = guipopover.new_mouse_popover(widget, _clip_menu, rect, Gtk.PositionType.TOP)
 
@@ -267,6 +274,7 @@ def audio_clip_popover_menu_show(widget, clip, track, x, y, callback):
         _fill_clone_filters_menu(clone_sub_menu, callback, False, True)
         filters_section.append_submenu(_("Clone Filter"), clone_sub_menu)
         add_menu_action(filters_section, _("Clear Filters"), "audioclipmenu.clearfilters",  ("clear_filters", None), callback)
+        add_menu_action(filters_section, _("Paste Filters"), "audioclipmenu.pastefilters",  ("paste_filters", None), callback)
         _audio_clip_menu.append_section(None, filters_section)
 
         edit_bottom_section = Gio.Menu.new()
@@ -310,7 +318,7 @@ def multi_clip_popover_menu_show(widget, clip, track, x, y, callback):
         transition_popover_menu_show(widget, clip, track, x, y, callback)
         return
 
-    global _multi_clip_popover, _multi_clip_menu, _multi_audio_section
+    global _multi_clip_popover, _multi_clip_menu, _multi_audio_section, _multi_sync_section
 
     if _multi_clip_menu == None:
         _multi_clip_menu = guipopover.menu_clear_or_create(_multi_clip_menu)
@@ -319,6 +327,10 @@ def multi_clip_popover_menu_show(widget, clip, track, x, y, callback):
         _fill_multi_audio_section(_multi_audio_section, clip, track, callback)
         _multi_clip_menu.append_section(None, _multi_audio_section)
 
+        _multi_sync_section = Gio.Menu.new()
+        _fill_multi_sync_section(_multi_sync_section, clip, track, callback)
+        _multi_clip_menu.append_section(None, _multi_sync_section)
+            
         container_section = Gio.Menu.new()
         add_menu_action(container_section, _("Create Container Clip From Selected Clips"), "multiclipmenu.createmulticompound",  ("create_multi_compound", None), callback)
         _multi_clip_menu.append_section(None, container_section)
@@ -331,17 +343,25 @@ def multi_clip_popover_menu_show(widget, clip, track, x, y, callback):
         _fill_clone_filters_menu(clone_sub_menu, callback, True, False)
         filters_section.append_submenu(_("Clone Filter"), clone_sub_menu)
         add_menu_action(filters_section, _("Clear Filters"), "multiclipmenu.clearfilters",  ("clear_filters", None), callback)
+        add_menu_action(filters_section, _("Paste Filters"), "multiclipmenu.pastefilters",  ("paste_filters", None), callback)
         _multi_clip_menu.append_section(None, filters_section)
 
         delete_section = Gio.Menu.new()
         add_menu_action(delete_section, _("Delete"), "multiclipmenu.delete",  ("delete", None), callback)
         add_menu_action(delete_section, _("Lift"), "multiclipmenu.lift",  ("lift", None), callback)
+        add_menu_action(delete_section, _("Ripple Delete Selection Range"), "multiclipmenu.ripplerange",  ("ripplerangeselection", None), callback)
         _multi_clip_menu.append_section(None, delete_section)
 
+        mark_section = Gio.Menu.new()
+        add_menu_action(mark_section, _("Mark Selection Range"), "multiclipmenu.markselectionrange",  ("mark_selection_range", None), callback)
+        _multi_clip_menu.append_section(None, mark_section)
+    
     else: # Menu items with possible state changes need to recreated.
         guipopover.menu_clear_or_create(_multi_audio_section)
         _fill_multi_audio_section(_multi_audio_section, clip, track, callback)
-
+        guipopover.menu_clear_or_create(_multi_sync_section)
+        _fill_multi_sync_section(_multi_sync_section, clip, track, callback)
+        
     rect = guipopover.create_rect(x, y)
     _multi_clip_popover = guipopover.new_mouse_popover(widget, _multi_clip_menu, rect, Gtk.PositionType.TOP)
 
@@ -391,6 +411,7 @@ def transition_popover_menu_show(widget, clip, track, x, y, callback):
         _fill_clone_filters_menu(clone_sub_menu, callback, False, False, True)
         filters_section.append_submenu(_("Clone Filter"), clone_sub_menu)
         add_menu_action(filters_section, _("Clear Filters"), "transitionclipmenu.clearfilters",  ("clear_filters", None), callback)
+        add_menu_action(filters_section, _("Paste Filters"), "transitionclipmenu.pastefilters",  ("paste_filters", None), callback)
         _transition_menu.append_section(None, filters_section)
 
     else: # Menu items with possible state changes need to recreated.
@@ -405,17 +426,21 @@ def _fill_multi_audio_section(multi_audio_section, clip, track, callback):
     if clip.media_type == appconsts.IMAGE_SEQUENCE or clip.media_type == appconsts.IMAGE or clip.media_type == appconsts.PATTERN_PRODUCER:
         active = False
     add_menu_action(multi_audio_section, _("Split Audio"), "multiclipmenu.multisplitaudio",  ("multi_split_audio", None), callback, active)
-    active = (track.id == current_sequence().first_video_index)
+    active = True
     if clip.media_type == appconsts.IMAGE_SEQUENCE or clip.media_type == appconsts.IMAGE or clip.media_type == appconsts.PATTERN_PRODUCER:
         active = False
     add_menu_action(multi_audio_section, _("Split Audio Synched"), "multiclipmenu.multisplitaudiosynched",  ("multi_split_audio_synched", None), callback, active)
     if clip.media_type == appconsts.IMAGE_SEQUENCE or clip.media_type == appconsts.IMAGE or clip.media_type == appconsts.PATTERN_PRODUCER:
         active = False
-    else:
-        active = True
+
     add_menu_action(multi_audio_section, _("Mute Audio"), "multiclipmenu.muteaudio",  ("multi_mute_audio", None), callback, active)
     add_menu_action(multi_audio_section, _("Unmute Audio"), "multiclipmenu.unmuteaudio",  ("multi_unmute_audio", None), callback, active)
-    
+
+def _fill_multi_sync_section(sync_section, clip, track, callback):
+    add_menu_action(sync_section,_("Select Sync Parent Clip..."), "clipmenu.multisetmaster",  ("multi_set_master", None), callback)
+    add_menu_action(sync_section,_("Resync"), "clipmenu.multiresync",  ("multi_resync", None), callback)
+    add_menu_action(sync_section,_("Clear Sync Relations"), "clipmenu.multiclearsyncrel",  ("multi_clear_sync_rel", None), callback)
+
 def _fill_audio_menu(audio_submenu, clip, track, callback):
     if track.type == appconsts.VIDEO:
         active = True
@@ -423,7 +448,7 @@ def _fill_audio_menu(audio_submenu, clip, track, callback):
             active = False
         add_menu_action(audio_submenu, _("Split Audio"), "clipmenu.splitaudio",  ("split_audio", None), callback, active)
 
-        active = (track.id == current_sequence().first_video_index)
+        active = True
         if clip.media_type == appconsts.IMAGE_SEQUENCE or clip.media_type == appconsts.IMAGE or clip.media_type == appconsts.PATTERN_PRODUCER:
             active = False
         add_menu_action(audio_submenu, _("Split Audio Synched"), "clipmenu.splitaudiosynched", ("split_audio_synched", None), callback, active)
@@ -504,16 +529,18 @@ def _fill_edit_actions_menu(edit_actions_menu, clip, track, callback):
     del_section = Gio.Menu.new()
     add_menu_action(del_section,_("Delete"), "clipmenu.delete",  ("delete", None), callback)
     add_menu_action(del_section,_("Lift"), "clipmenu.delete",  ("lift", None), callback)
+    add_menu_action(del_section, _("Ripple Delete Clip Range"), "clipmenu.ripplerange",  ("ripplerange", None), callback)
     edit_actions_menu.append_section(None, del_section)
 
-    if track.id != current_sequence().first_video_index:
-        sync_section = Gio.Menu.new()
-        if clip.sync_data != None:
-            add_menu_action(sync_section,_("Resync"), "clipmenu.resync",  ("resync", None), callback)
-            add_menu_action(sync_section,_("Clear Sync Relation"), "clipmenu.clearsyncrel",  ("clear_sync_rel", None), callback)
-        else:
-            add_menu_action(sync_section,_("Select Sync Parent Clip..."), "clipmenu.setmaster",  ("set_master", None), callback)
-        edit_actions_menu.append_section(None, sync_section)
+    sync_section = Gio.Menu.new()
+
+    active = (clip.sync_data != None)
+    add_menu_action(sync_section,_("Resync"), "clipmenu.resync",  ("resync", None), callback, active)
+    add_menu_action(sync_section,_("Clear Sync Relation"), "clipmenu.clearsyncrel",  ("clear_sync_rel", None), callback, active)
+
+    active = (clip.sync_data == None)
+    add_menu_action(sync_section,_("Select Sync Parent Clip..."), "clipmenu.setmaster",  ("set_master", None), callback, active)
+    edit_actions_menu.append_section(None, sync_section)
 
     length_section = Gio.Menu.new()
     add_menu_action(length_section, _("Set Clip Length..."), "clipmenu.length",  ("length", None), callback)
@@ -544,8 +571,14 @@ def _fill_select_menu(select_menu, callback, is_audio_select=False):
         pre_id = "audio"
     else:
         pre_id = ""
-    add_menu_action(select_menu, _("All Clips After"), pre_id + "clipmenu.selectallafter",  ("select_all_after", None), callback)
-    add_menu_action(select_menu, _("All Clips Before"), pre_id + "clipmenu.selectallbefore",  ("select_all_before", None), callback)
+    select_section = Gio.Menu.new()
+    add_menu_action(select_section, _("All Clips After"), pre_id + "clipmenu.selectallafter",  ("select_all_after", None), callback)
+    add_menu_action(select_section, _("All Clips Before"), pre_id + "clipmenu.selectallbefore",  ("select_all_before", None), callback)
+    select_menu.append_section(None, select_section)
+
+    mark_section = Gio.Menu.new()
+    add_menu_action(mark_section, _("Mark Clip Range"), pre_id + "clipmenu.markcliprange",  ("mark_clip_range", None), callback)
+    select_menu.append_section(None, mark_section)
 
 def _fill_filters_menus(sub_menu, callback, item_id, action_id):
     j = 0
@@ -589,17 +622,31 @@ def _fill_compositors_section(compositor_section, clip, track, callback):
 def _fill_title_section(title_section, clip, callback):
     active = (clip.titler_data != None)
     add_menu_action(title_section, _("Edit Title"), "clipmenu.edittitle",  ("edit_title", None), callback, active)
-    
+
 def _fill_generator_section(generator_section, clip, callback):
+        
     active = (clip.container_data != None)
     genactive = active
     if clip.container_data != None and clip.container_data.container_type != appconsts.CONTAINER_CLIP_FLUXITY:
         genactive = False
+    seq_link_active = False 
+    if clip.container_data != None and clip.container_data.container_type == appconsts.CONTAINER_CLIP_SEQUENCE_LINK:
+        seq_link_active = True
+
     add_menu_action(generator_section, _("Edit Generator Properties..."), "clipmenu.ccedit",  ("cc_edit_program", None), callback, genactive)
     add_menu_action(generator_section, _("Create Cloned Generator..."), "clipmenu.ccclonegen",  ("cc_clone_generator", None), callback, genactive)
-    add_menu_action(generator_section, _("Generator/Container Render Actions"), "clipmenu.ccrender",  ("cc_render_clip", None), callback, active)
-    add_menu_action(generator_section, _("Switch to Unrendered Media"), "clipmenu.ccgotounrendered", ("cc_go_to_underdered", None),  callback, active)
+    add_menu_action(generator_section, _("Update Sequence Link Clip"), "clipmenu.updateseqlink", ("cc_update_seq_link", None),  callback, seq_link_active)
 
+    generator_section.append_submenu(_("Generator and Container Rendering"), _generator_sub_menu)
+        
+def _fill_generator_render_section(generator_section, clip, callback):
+    active = (clip.container_data != None)
+    
+    add_menu_action(generator_section, _("Render Clip..."), "clipmenu.ccrender",  ("cc_render_clip", None), callback, active)
+    add_menu_action(generator_section, _("Render Settings..."), "clipmenu.ccencoding",  ("cc_render_settings", None), callback, active)
+    add_menu_action(generator_section, _("Switch to Unrendered Media"), "clipmenu.ccgotounrendered", ("cc_go_to_underdered", None),  callback, active)
+    add_menu_action(generator_section, _("Set Default Encoding..."), "clipmenu.ccdefaultencoding", ("cc_default_encoding", None),  callback, active)
+    
 def _fill_audio_clip_sync_section(sync_section, clip, callback):
     is_synched = (clip.sync_data != None)
     add_menu_action(sync_section, _("Resync"), "audioclipmenu.resync", ("resync", None), callback, is_synched)
@@ -621,6 +668,7 @@ def _fill_audio_edit_actions_menu(edit_actions_menu, callback):
     del_section = Gio.Menu.new()
     add_menu_action(del_section,_("Delete"), "audioclipmenu.delete",  ("delete", None), callback)
     add_menu_action(del_section,_("Lift"), "audioclipmenu.delete",  ("lift", None), callback)
+    add_menu_action(del_section, _("Ripple Delete Clip Range"), "audioclipmenu.ripplerange",  ("ripplerange", None), callback)
     edit_actions_menu.append_section(None, del_section)
 
     length_section = Gio.Menu.new()
@@ -679,6 +727,7 @@ def kftool_popover_menu_show(widget, kftool, x, y, callback, callback_snapping):
         _kftool_menu.append_section(None, plyhead_section)
 
         exit_section = Gio.Menu.new()
+        add_menu_action(exit_section, _("Open in Edit Panel Keyframe Editor"), "kftoolmenu.editpanel",  ("editpanel", None), callback)
         add_menu_action(exit_section, _("Exit Edit"), "kftoolmenu.exit",  ("exit", None), callback)
         _kftool_menu.append_section(None, exit_section)
 
