@@ -161,7 +161,8 @@ class FilterInfo:
 
         #  Extra editors that handle properties that have been set "no_editor"
         e_node_list = filter_node.getElementsByTagName(EXTRA_EDITOR)
-        self.extra_editors = propertyparse.node_list_to_extraeditors_array(e_node_list)  
+        self.extra_editors = propertyparse.node_list_to_extraeditors_array(e_node_list)
+        self.extra_editors_args = propertyparse.node_list_to_extraeditors_args_dict(e_node_list)
 
         # Non-MLT properties are persistent values like properties. but they have values are not directly written out as MLT properties.
         p_node_list = filter_node.getElementsByTagName(NON_MLT_PROPERTY)
@@ -220,7 +221,7 @@ class FilterObject:
              self.mlt_filter.set("disable", str(1))
 
     def replace_values(self, clip):
-        # We need to initialize some calues based clip length and need wait until clip for
+        # We need to initialize some values based clip length and need wait until clip for
         # filter is known, replace at object creation is done before clip is available
         replacement_happened = propertyparse.replace_values_using_clip_data(self.properties, self.info, clip)
         if replacement_happened == True:
@@ -375,7 +376,7 @@ def load_filters_xml(services):
             global _volume_filter_info
             _volume_filter_info = filter_info
 
-        if filter_info.mlt_service_id == "shape": # we need this filter to do mutes so save reference to it
+        if filter_info.mlt_service_id == "shape":
             global _shape_filter_info
             _shape_filter_info = filter_info
 
