@@ -65,7 +65,7 @@ NOT_FOUND = "/not_found_not_found/not_found"
 # Used to send messages when loading project, set at callsite.
 load_dialog = None
 
-# These are used to recrete parenting relationships
+# These are used to recreate parenting relationships
 all_clips = {}
 sync_clips = []
 
@@ -239,6 +239,10 @@ def get_p_playlist(playlist):
 
     s_playlist.clips = add_clips
     
+    # Replace parent track with its id.
+    if s_playlist.parent_track != None:
+        s_playlist.parent_track = s_playlist.parent_track.id
+    
     # Remove unpicleable attributes
     remove_attrs(s_playlist, PLAY_LIST_REMOVE)
    
@@ -341,10 +345,12 @@ def get_p_compositors(compositors):
 
 def get_p_sync_data(sync_data):
     s_sync_data = copy.copy(sync_data)
-    if isinstance( sync_data.master_clip, int ): # When saving relinked projects sync_data.master_clip 
-                                                   # is already int and does not need to be replaced
+    if isinstance( sync_data.master_clip, int ):   # When saving relinked projects sync_data.master_clip 
+                                                   # and s_sync_data.master_clip_track are already ints
+                                                   # because they haven't been replacved with live objects.
         return s_sync_data
     s_sync_data.master_clip = sync_data.master_clip.id
+    s_sync_data.master_clip_track = sync_data.master_clip_track.id
     return s_sync_data
 
 def remove_attrs(obj, remove_attrs):
@@ -511,7 +517,7 @@ def fill_sequence_mlt(seq, SAVEFILE_VERSION):
     # Compositing mode COMPOSITING_MODE_TOP_DOWN_AUTO_FOLLOW was removed 2.6->
     persistancecompat.FIX_DEPRECATED_SEQUENCE_COMPOSITING_MODE(seq)
     
-    # Grap and replace py tracks. Do this way to use same create
+    # Grab and replace py tracks. Do this way to use same create
     # method as when originally created.
     py_tracks = seq.tracks
     seq.tracks = []
@@ -522,6 +528,7 @@ def fill_sequence_mlt(seq, SAVEFILE_VERSION):
     # Create and fill MLT tracks.
     for py_track in py_tracks:
         mlt_track = seq.add_track(py_track.type)
+        persistancecompat.FIX_MISSING_TRACK_ATTRS(mlt_track)
         if py_track.id == len(py_tracks) - 1:
             continue # Do not try to fill hidden track even if somehow a clip was saved there.
         fill_track_mlt(mlt_track, py_track)
@@ -529,7 +536,7 @@ def fill_sequence_mlt(seq, SAVEFILE_VERSION):
         if hasattr(mlt_track, "gain_filter"): # Hidden track and black track do not have these
             mlt_track.gain_filter.set("gain", str(mlt_track.audio_gain))
         if mlt_track.audio_pan != appconsts.NO_PAN:
-            seq.add_track_pan_filter(mlt_track, mlt_track.audio_pan) # only rtack with non-center pan values have pan filters
+            seq.add_track_pan_filter(mlt_track, mlt_track.audio_pan) # only track with non-center pan values have pan filters
     
     # Create and connect compositors.
     mlt_compositors = []
@@ -576,12 +583,25 @@ def fill_sequence_mlt(seq, SAVEFILE_VERSION):
         clip, track = clip_n_track
         try:
             master_clip = all_clips[clip.sync_data.master_clip] # master clip has been replaced with its id on save
-            clip.sync_data.master_clip = master_clip # put back reference to master clip
-            resync.clip_added_to_timeline(clip, track) # save data to enagble sync states monitoring after eddits
+            if hasattr(clip.sync_data, "master_clip_track"):
+                master_clip_track = seq.tracks[clip.sync_data.master_clip_track]
+            else:
+                # All sync parents were previously on track V1.
+                master_clip_track = seq.tracks[seq.first_video_index]
+            # put back references to objects
+            clip.sync_data.master_clip = master_clip
+            clip.sync_data.master_clip_track = master_clip_track
+            resync.clip_added_to_timeline(clip, track) # save data to enagble sync states monitoring after edits
         except KeyError:
             clip.sync_data = None # masterclip no longer on track V1
             resync.clip_removed_from_timeline(clip)
 
+    # Replace track ids with track objects on parented tracks.
+    for i in range(1, len(seq.tracks) - 1):
+        track = seq.tracks[i]
+        if track.parent_track != None:
+            track.parent_track = seq.tracks[track.parent_track]
+
     # This sets MLT properties that actually do mute
     seq.set_tracks_mute_state()
 
