@@ -82,8 +82,8 @@ COMPOSITE_EDITOR_BUILDER = "composite_properties"           # Creates a single r
 REGION_EDITOR_BUILDER = "region_properties"                 # Creates a single row editor for multiple properties of region transition
 ROTATION_GEOMETRY_EDITOR_BUILDER = "rotation_geometry_editor" # Creates a single editor for multiple geometry values
 INFOANDTIPS = "infotips"                                    # Displays link to docs Info & Tips page 
-ANALYZE_STABILIZE = "analyzestabilize"                      # Launches stabilizing analyzis for clip
-ANALYZE_MOTION = "analyzemotion"                            # Launches motion tracking analyzis for clip
+ANALYZE_STABILIZE = "analyzestabilize"                      # Launches stabilizing analysis for clip
+ANALYZE_MOTION = "analyzemotion"                            # Launches motion tracking analysis for clip
 APPLY_MOTION = "applymotion"                                # Applies motion tracking as source image movement.
 APPLY_FILTER_MASK_MOTION = "applyfiltermaskmotion"          # Applies motion tracking as filter mask.
 SCALE_DIGITS = "scale_digits"                               # Number of decimal digits displayed in a widget
@@ -684,9 +684,6 @@ class FadeLengthEditor(Gtk.HBox):
 def _get_fade_length_editor(editable_property):
     return FadeLengthEditor(editable_property)
 
-
-
-
 def _get_file_select_editor(editable_property):
     """
     Returns GUI component for selecting file of determined type
@@ -716,7 +713,7 @@ def _get_file_select_editor(editable_property):
     file_select_button.set_size_request(210, 28)
     # TODO: check this out
     if hasattr(editable_property, "value") and editable_property.value != '' and editable_property.value != '""':
-        file_select_button.set_uri(GLib.filename_to_uri(editable_property.value))
+        file_select_button.set_filename(editable_property.value)
 
     file_select_label = Gtk.Label(label=editable_property.get_display_name())
 
