@@ -26,6 +26,8 @@ try:
     import mlt7 as mlt
 except:
     import mlt
+
+import hashlib
 import os
 
 import appconsts
@@ -116,7 +118,8 @@ class Sequence:
         self.watermark_file_path = None
         self.seq_len = 0 # used in trim crash hack, remove when fixed
         self.compositing_mode = initial_comp_mode
-
+        self.uid = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
+ 
         # MLT objects for a multitrack sequence
         self.init_mlt_objects()
         
@@ -257,6 +260,7 @@ class Sequence:
         
         # Add method that returns track name
         new_track.get_name = lambda : utils.get_track_name(new_track, self) 
+        new_track.parent_track = None
         
         return new_track
 
@@ -505,6 +509,7 @@ class Sequence:
         clip.titler_data = None # titler_data != None defines clips as a title clip that can be edited in Titler.
         clip.slowmo_data = None # tuple (slowmo_type, orig_media_file_path, slowmo_clip_media_area, slowmo_speed_data,
                                 #        orig_media_in, orig_media_out)
+        clip.link_seq_data = None # link_seq_data is uid of linked sequence
 
     def clone_track_clip(self, track, index):
         orig_clip = track.clips[index]
@@ -518,6 +523,7 @@ class Sequence:
         if clip.media_type != appconsts.PATTERN_PRODUCER:
             clone_clip = self.create_file_producer_clip(clip.path, None, False, clip.ttl) # file producer
         else:
+            # Pattern producers are deprecated, look to remove this.
             clone_clip = self.create_pattern_producer(clip.create_data) # pattern producer
         self.clone_clip_and_filters(clip, clone_clip)
         return clone_clip
@@ -528,10 +534,11 @@ class Sequence:
         used in another clip's place, but not id, master_clip and selection
         properties that are part of original clips state in sequence.
         """
+        clone_clip.name = clip.name
         clone_clip.clip_in = clip.clip_in
         clone_clip.clip_out = clip.clip_out
         clone_clip.filters = []
-        
+    
         for f in clip.filters:
             clone_filter = mltfilters.clone_filter_object(f, self.profile)
             clone_clip.attach(clone_filter.mlt_filter)
@@ -1020,6 +1027,33 @@ class Sequence:
                 
         return cut_frame
 
+    def find_parent_clip_for_clip_start(self, parent_track, clip_start_frame):
+        parent_clip = None
+        last_pos_diff = None
+        for i in range(0, len(parent_track.clips)):
+
+            clip = parent_track.clips[i]            
+            parent_clip_start_frame = parent_track.clip_start(i)
+            if clip.is_blanck_clip == True:
+                continue
+            
+            new_diff = parent_clip_start_frame - clip_start_frame
+
+            if parent_clip == None:
+                parent_clip = clip
+                last_pos_diff = new_diff
+            else:
+                if new_diff >= 0:
+                    if abs(new_diff) <= abs(last_pos_diff):
+                        return clip
+                    else:
+                        return parent_clip
+                else:
+                    parent_clip = clip
+                    last_pos_diff = new_diff
+
+        return parent_clip
+
     def find_prev_cut_frame(self, tline_frame):
         """
         Returns frame of next cut in active tracks relative to timeline.
