@@ -102,7 +102,7 @@ def load_shortcuts():
 def set_keyboard_shortcuts():
     global _keyboard_actions, _editable
     prefs = editorpersistance.prefs
-    print("Keyboard shortcuts file:",  editorpersistance.prefs.shortcuts)
+    print("Keyboard shortcuts file:", editorpersistance.prefs.shortcuts)
     _modifier_dict = {}
 
     # Make sure that whatever is in preferences is a valid and exists file. If it's not in shortcut_files it's not valid
@@ -141,9 +141,9 @@ def set_keyboard_shortcuts():
                     # to easily compare with any entered combo of the modifiers. In fact, CTRL+ALT becomes the
                     # same as ALT+CTRL and Alt+Ctrl- it will all be +acllrtt
                     if event.get('modifiers') == None:
-                        _modifier_dict[''.join(sorted(re.sub('[\s]','','None'.lower())))] = event.get('code')
+                        _modifier_dict[''.join(sorted(re.sub(r'[\s]','','None'.lower())))] = event.get('code')
                     else:
-                        _modifier_dict[''.join(sorted(re.sub('[\s]','',event.get('modifiers').lower())))] = event.get('code')
+                        _modifier_dict[''.join(sorted(re.sub(r'[\s]','',event.get('modifiers').lower())))] = event.get('code')
                     _keyboard_actions[event.text] = _modifier_dict
         _editable = root.get('editable')
     except:
@@ -260,7 +260,7 @@ def change_custom_shortcut(code, key_val_name, mods_list, add_event=False):
 
     # Add new element if so ordered.
     if add_event == True:
-        new_event = etree.Element("event")    
+        new_event = etree.Element("event")
         new_event.text = key_val_name
         new_event.set('code', code)
         shortcuts_node = root.find("shortcuts")
@@ -304,19 +304,23 @@ def is_blocked_shortcut(key_val, mods_list):
         if key_val == r_key_val:
             if collections.Counter(mods_list) == collections.Counter(r_mods_list):
                 return True
-                
+
     return False
 
 def get_shortcut_info(root, code):
-    events = root.iter('event')
+    try:
+        events = root.iter('event')
+
+        for event in events:
+            if event.get('code') == code:
+                mod_name = _get_mod_string(event)
+                if mod_name != "":
+                    mod_name = mod_name + " + "
+                return (mod_name + _key_names[event.text], _keyboard_action_names[code]) 
+    except:
+        print("error in get_shortcut_info, event.text:", event.text)
+        pass
 
-    for event in events:
-        if event.get('code') == code:
-            mod_name = _get_mod_string(event)
-            if mod_name != "":
-                mod_name = mod_name + " + "
-            return (mod_name + _key_names[event.text], _keyboard_action_names[code]) 
-    
     return (None, None)
 
 def get_shortcut_gtk_code(root, code):
@@ -356,6 +360,9 @@ def _set_keyboard_action_names():
     _keyboard_action_names['to_mark_in'] =  _("Go To Mark In")
     _keyboard_action_names['to_mark_out'] =  _("Go To Mark Out")
     _keyboard_action_names['clear_io_marks'] =  _("Clear In/Out Marks")
+    _keyboard_action_names['clear_mark_in'] =  _("Clear Mark In")
+    _keyboard_action_names['clear_mark_out'] =  _("Clear Mark Out")
+    _keyboard_action_names['play'] = _("Play")
     _keyboard_action_names['play_pause'] = _("Start / Stop Playback")
     _keyboard_action_names['prev_cut'] = _("Prev Edit/Mark")
     _keyboard_action_names['next_cut'] = _("Next Edit/Mark")
@@ -389,6 +396,8 @@ def _set_keyboard_action_names():
     _keyboard_action_names['zoom_out'] = _("Zoom Out")
     _keyboard_action_names['zoom_in'] =  _("Zoom In")
     _keyboard_action_names['switch_monitor'] = _("Switch Monitor Source")
+    _keyboard_action_names['display_clip_in_monitor'] = _("Display Clip In Monitor")
+    _keyboard_action_names['display_sequence_in_monitor'] = _("Display Sequence In Monitor")
     _keyboard_action_names['add_marker'] = _("Add Mark")
     _keyboard_action_names['enter_edit'] =  _("Complete Keyboard Trim Edit")
     _keyboard_action_names['nudge_back'] =  _("Nudge Move Selection Back 1 Frame")
@@ -396,6 +405,7 @@ def _set_keyboard_action_names():
     _keyboard_action_names['nudge_back_10'] =  _("Nudge Move Selection Back 10 Frames")
     _keyboard_action_names['nudge_forward_10'] =  _("Nudge Move Selection Forward 10 Frames")
     _keyboard_action_names['open_next'] =  _("Open Next Media Item In Monitor")
+    _keyboard_action_names['open_prev'] =  _("Open Previous Media Item In Monitor")
     _keyboard_action_names['clear_filters'] = _("Clear Filters")
     _keyboard_action_names['sync_all'] = _("Sync All Compositors")
     _keyboard_action_names['select_next'] = _("Open Next Clip In Filter Editor")
@@ -407,6 +417,10 @@ def _set_keyboard_action_names():
     _keyboard_action_names['toggle_track_output'] = _('Enable/Disable Selected Clip Track Output')
     _keyboard_action_names['tline_page_up'] = _('Timeline Vertical Page Up')
     _keyboard_action_names['tline_page_down'] = _('Timeline Vertical Page Down')
+    _keyboard_action_names['move_media'] = _('Move Selected Media Items')
+    _keyboard_action_names['monitor_show_video'] = _('Show Video')
+    _keyboard_action_names['monitor_show_scope'] = _('Show Vectorscope')
+    _keyboard_action_names['monitor_show_rgb'] = _('Show RGB Parade')
 
 def _set_key_names():
     global _key_names, _mod_names, _gtk_mod_names
