@@ -377,6 +377,10 @@ def splice_out_button_pressed():
     Removes 1 - n long continuous clip range from track and closes
     the created gap.
     """
+    if boxmove.box_selection_data != None:
+        boxmove.box_selection_splice_out()
+        return
+
     if movemodes.selected_track == -1:
         return
 
@@ -457,7 +461,7 @@ def _attempt_clip_cover_delete(clip, track, index):
         cover_form_clip = track.clips[movemodes.selected_range_in - 1]
         cover_to_clip = track.clips[movemodes.selected_range_in + 1]
         
-        real_length = clip.get_length() # this the mlt finction giving media length, not length on timeline
+        real_length = clip.get_length() # this the mlt function giving media length, not length on timeline
 
         to_part = real_length // 2
         from_part = real_length - to_part
@@ -497,6 +501,10 @@ def lift_button_pressed():
     Removes 1 - n long continuous clip range from track and fills
     the created gap with a blank clip
     """
+    if boxmove.box_selection_data != None:
+        boxmove.box_selection_lift()
+        return
+
     if movemodes.selected_track == -1:
         return
 
@@ -831,6 +839,16 @@ def resync_button_pressed():
 def resync_track_button_pressed():
     syncsplitevent.resync_track()
 
+def set_track_sync_button_pressed():
+    if movemodes.selected_track != -1:
+        child_track = current_sequence().tracks[movemodes.selected_track]
+        syncsplitevent.set_track_clips_sync(child_track)
+
+def clear_track_sync_button_pressed():
+    if movemodes.selected_track != -1:
+        child_track = current_sequence().tracks[movemodes.selected_track]
+        syncsplitevent.clear_track_clips_sync(child_track)
+        
 def sync_compositor(compositor):
     track = current_sequence().tracks[compositor.transition.b_track] # b_track is source track where origin clip is
     origin_clip = None
@@ -1014,7 +1032,12 @@ def do_timeline_objects_paste():
         
         # Paste clips.
         # Clips are pasted after track content end.
-        if track.get_length() < tline_pos:
+        if track.get_length() - 2 < tline_pos:
+            data = {"track":track,
+                    "clips":new_clips}
+            action = edit.append_multiple_action(data)
+            action.do_edit()
+        elif track.get_length() < tline_pos:
             blank_length = tline_pos - track.get_length() 
             # Do edit
             data = {"track":track,
@@ -1037,12 +1060,25 @@ def do_timeline_objects_paste():
             if paste_on_cut == True:
                 editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
             else:
-                cut_action = cut_pressed(True)
+                # Get index and clip
+                index = track.get_clip_index_at(int(tline_pos))
+                clip = track.clips[index]            
+
+                # Get cut frame in clip frames
+                clip_start_in_tline = track.clip_start(index)
+                clip_frame = tline_pos - clip_start_in_tline + clip.clip_in
+
+                # Do edit
+                data = {"track":track,
+                        "index":index,
+                        "clip":clip,
+                        "clip_cut_frame":clip_frame}
+                cut_action = edit.cut_action(data)
+        
                 multi_insert_action = editevent.do_multiple_clip_insert(track, paste_clips, tline_pos, True)
                 actions = [cut_action, multi_insert_action]
                 consolidated_action = edit.ConsolidatedEditAction(actions)
                 consolidated_action.do_consolidated_edit()
-                #editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
     else:
         # Paste clips
         editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
