@@ -37,12 +37,14 @@ from editorstate import PLAYER
 import movemodes
 import projectaction
 import snapping
+import syncsplitevent
 import tlinewidgets
 import updater
 
 
 _menu_track_index = None
-        
+
+
 # --------------------------------------- menu events
 def _track_menu_item_activated(widget, action, data):
     track, item_id, selection_data = data
@@ -74,6 +76,32 @@ def unlock_track(track_index):
     track.edit_freedom = appconsts.FREE
     updater.repaint_tline()
 
+
+def set_track_sync(track_index):
+    child_track = get_track(track_index)
+    syncsplitevent.set_track_clips_sync(child_track)
+
+def reset_treack_sync(track_index):
+    child_track = get_track(track_index)
+    parent_track = child_track.parent_track
+    syncsplitevent.do_set_track_clips_sync(child_track, parent_track)
+
+def clear_track_sync(track_index):
+    track = get_track(track_index)
+    if len(track.clips) == 0:
+        track.parent_track = None
+        updater.repaint_tline()
+        return
+
+    syncsplitevent.clear_track_clips_sync(track)
+
+def resync_track(track_index):
+    track = get_track(track_index)
+    if len(track.clips) == 0:
+        return
+
+    syncsplitevent.resync_selected_track(track)
+
 def toggle_track_output():
     if movemodes.selected_track == -1:
         return
@@ -273,6 +301,12 @@ def _tline_properties_item_activated(action, event, msg):
         editorpersistance.prefs.audio_scrubbing = new_state
         editorpersistance.save()
         PLAYER().set_scrubbing(new_state)
+    elif msg == "wideslip":
+        editorpersistance.prefs.wide_multitrim_slip = new_state
+        editorpersistance.save()
+    elif msg == "disabledrag":
+        editorpersistance.prefs.disable_drag_when_selected = new_state
+        editorpersistance.save()
     else: # media thumbnails
         editorstate.display_clip_media_thumbnails = new_state
         updater.repaint_tline()
@@ -327,9 +361,7 @@ def track_center_pressed(data):
         y_off = press_y - tlinewidgets._get_track_y(track.id)
         ICON_WIDTH = 14
         ICON_HEIGHT = 10
-        if editorpersistance.prefs.double_track_hights == True:
-            ICON_WIDTH = 28
-            ICON_HEIGHT = 20
+
         X_CORR_OFF = 4 # icon edge not on image left edge
         if press_x > tlinewidgets.COLUMN_LEFT_PAD + X_CORR_OFF and press_x < tlinewidgets.COLUMN_LEFT_PAD + ICON_WIDTH + X_CORR_OFF:
             # Mute icon x area hit
@@ -391,4 +423,8 @@ def track_center_pressed(data):
 
 POPUP_HANDLERS = {"lock":lock_track,
                   "unlock":unlock_track,
-                  "mute_track":mute_track}
+                  "mute_track":mute_track,
+                  "clearsync":clear_track_sync,
+                  "resync":resync_track,
+                  "setsync":set_track_sync,
+                  "ressetsync":reset_treack_sync}
